// SPDX-License-Identifier: MIT
// Copyright (C) 2018-present iced project and contributors

// ⚠️This file was generated by GENERATOR!🦹‍♂️

#[rustfmt::skip]
pub(super) static TBL_DATA: &[u8] = &[
	// handlers_FPU_D8_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xEE, 0x03,// Fadd_m32fp

	// 1 = 0x01
	0x73,// Mf_1
		0xEF, 0x03,// Fmul_m32fp

	// 2 = 0x02
	0x73,// Mf_1
		0xF0, 0x03,// Fcom_m32fp

	// 3 = 0x03
	0x73,// Mf_1
		0xF1, 0x03,// Fcomp_m32fp

	// 4 = 0x04
	0x73,// Mf_1
		0xF2, 0x03,// Fsub_m32fp

	// 5 = 0x05
	0x73,// Mf_1
		0xF3, 0x03,// Fsubr_m32fp

	// 6 = 0x06
	0x73,// Mf_1
		0xF4, 0x03,// Fdiv_m32fp

	// 7 = 0x07
	0x73,// Mf_1
		0xF5, 0x03,// Fdivr_m32fp

	// handlers_FPU_D8_high
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0xAE,// ST_STi
		0xF6, 0x03,// Fadd_st0_sti

	// 1 = 0x01
	0xAE,// ST_STi
		0xF7, 0x03,// Fmul_st0_sti

	// 2 = 0x02
	0xAE,// ST_STi
		0xF8, 0x03,// Fcom_st0_sti

	// 3 = 0x03
	0xAE,// ST_STi
		0xF9, 0x03,// Fcomp_st0_sti

	// 4 = 0x04
	0xAE,// ST_STi
		0xFA, 0x03,// Fsub_st0_sti

	// 5 = 0x05
	0xAE,// ST_STi
		0xFB, 0x03,// Fsubr_st0_sti

	// 6 = 0x06
	0xAE,// ST_STi
		0xFC, 0x03,// Fdiv_st0_sti

	// 7 = 0x07
	0xAE,// ST_STi
		0xFD, 0x03,// Fdivr_st0_sti

	// handlers_FPU_D9_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xFE, 0x03,// Fld_m32fp

	// 1 = 0x01
	0x02,// Invalid

	// 2 = 0x02
	0x73,// Mf_1
		0xFF, 0x03,// Fst_m32fp

	// 3 = 0x03
	0x73,// Mf_1
		0x80, 0x04,// Fstp_m32fp

	// 4 = 0x04
	0x74,// Mf_2a
		0x81, 0x04,// Fldenv_m14byte

	// 5 = 0x05
	0x73,// Mf_1
		0x83, 0x04,// Fldcw_m2byte

	// 6 = 0x06
	0x75,// Mf_2b
		0x84, 0x04,// Fnstenv_m14byte
		0x86, 0x04,// Fnstenv_m28byte

	// 7 = 0x07
	0x73,// Mf_1
		0x88, 0x04,// Fnstcw_m2byte

	// handlers_FPU_D9_high
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0x8A, 0x04,// Fld_sti

	// 8 = 0x08
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0x8B, 0x04,// Fxch_st0_sti

	// 16 = 0x10
	0xA4,// Simple
		0x8C, 0x04,// Fnop

	// 17 = 0x11
	0x05,// Dup
		0x06,// 6
		0x02,// Invalid

	// 23 = 0x17
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xAB, 0x21,// Cyrix_D9D7
		0x80, 0x80, 0x40,// Cyrix

	// 24 = 0x18
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0x8D, 0x04,// Fstpnce_sti

	// 32 = 0x20
	0xA4,// Simple
		0x8E, 0x04,// Fchs

	// 33 = 0x21
	0xA4,// Simple
		0x8F, 0x04,// Fabs

	// 34 = 0x22
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xAC, 0x21,// Cyrix_D9E2
		0x80, 0x80, 0x40,// Cyrix

	// 35 = 0x23
	0x02,// Invalid

	// 36 = 0x24
	0xA4,// Simple
		0x90, 0x04,// Ftst

	// 37 = 0x25
	0xA4,// Simple
		0x91, 0x04,// Fxam

	// 38 = 0x26
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xAD, 0x21,// Ftstp
		0x80, 0x80, 0x40,// Cyrix

	// 39 = 0x27
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xAE, 0x21,// Cyrix_D9E7
		0x80, 0x80, 0x40,// Cyrix

	// 40 = 0x28
	0xA4,// Simple
		0x92, 0x04,// Fld1

	// 41 = 0x29
	0xA4,// Simple
		0x93, 0x04,// Fldl2t

	// 42 = 0x2A
	0xA4,// Simple
		0x94, 0x04,// Fldl2e

	// 43 = 0x2B
	0xA4,// Simple
		0x95, 0x04,// Fldpi

	// 44 = 0x2C
	0xA4,// Simple
		0x96, 0x04,// Fldlg2

	// 45 = 0x2D
	0xA4,// Simple
		0x97, 0x04,// Fldln2

	// 46 = 0x2E
	0xA4,// Simple
		0x98, 0x04,// Fldz

	// 47 = 0x2F
	0x02,// Invalid

	// 48 = 0x30
	0xA4,// Simple
		0x99, 0x04,// F2xm1

	// 49 = 0x31
	0xA4,// Simple
		0x9A, 0x04,// Fyl2x

	// 50 = 0x32
	0xA4,// Simple
		0x9B, 0x04,// Fptan

	// 51 = 0x33
	0xA4,// Simple
		0x9C, 0x04,// Fpatan

	// 52 = 0x34
	0xA4,// Simple
		0x9D, 0x04,// Fxtract

	// 53 = 0x35
	0xA4,// Simple
		0x9E, 0x04,// Fprem1

	// 54 = 0x36
	0xA4,// Simple
		0x9F, 0x04,// Fdecstp

	// 55 = 0x37
	0xA4,// Simple
		0xA0, 0x04,// Fincstp

	// 56 = 0x38
	0xA4,// Simple
		0xA1, 0x04,// Fprem

	// 57 = 0x39
	0xA4,// Simple
		0xA2, 0x04,// Fyl2xp1

	// 58 = 0x3A
	0xA4,// Simple
		0xA3, 0x04,// Fsqrt

	// 59 = 0x3B
	0xA4,// Simple
		0xA4, 0x04,// Fsincos

	// 60 = 0x3C
	0xA4,// Simple
		0xA5, 0x04,// Frndint

	// 61 = 0x3D
	0xA4,// Simple
		0xA6, 0x04,// Fscale

	// 62 = 0x3E
	0xA4,// Simple
		0xA7, 0x04,// Fsin

	// 63 = 0x3F
	0xA4,// Simple
		0xA8, 0x04,// Fcos

	// handlers_FPU_DA_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xA9, 0x04,// Fiadd_m32int

	// 1 = 0x01
	0x73,// Mf_1
		0xAA, 0x04,// Fimul_m32int

	// 2 = 0x02
	0x73,// Mf_1
		0xAB, 0x04,// Ficom_m32int

	// 3 = 0x03
	0x73,// Mf_1
		0xAC, 0x04,// Ficomp_m32int

	// 4 = 0x04
	0x73,// Mf_1
		0xAD, 0x04,// Fisub_m32int

	// 5 = 0x05
	0x73,// Mf_1
		0xAE, 0x04,// Fisubr_m32int

	// 6 = 0x06
	0x73,// Mf_1
		0xAF, 0x04,// Fidiv_m32int

	// 7 = 0x07
	0x73,// Mf_1
		0xB0, 0x04,// Fidivr_m32int

	// handlers_FPU_DA_high
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xB1, 0x04,// Fcmovb_st0_sti

	// 8 = 0x08
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xB2, 0x04,// Fcmove_st0_sti

	// 16 = 0x10
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xB3, 0x04,// Fcmovbe_st0_sti

	// 24 = 0x18
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xB4, 0x04,// Fcmovu_st0_sti

	// 32 = 0x20
	0x05,// Dup
		0x09,// 9
		0x02,// Invalid

	// 41 = 0x29
	0xA4,// Simple
		0xB5, 0x04,// Fucompp

	// 42 = 0x2A
	0x05,// Dup
		0x16,// 22
		0x02,// Invalid

	// handlers_FPU_DB_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xB6, 0x04,// Fild_m32int

	// 1 = 0x01
	0x73,// Mf_1
		0xB7, 0x04,// Fisttp_m32int

	// 2 = 0x02
	0x73,// Mf_1
		0xB8, 0x04,// Fist_m32int

	// 3 = 0x03
	0x73,// Mf_1
		0xB9, 0x04,// Fistp_m32int

	// 4 = 0x04
	0x02,// Invalid

	// 5 = 0x05
	0x73,// Mf_1
		0xBA, 0x04,// Fld_m80fp

	// 6 = 0x06
	0x02,// Invalid

	// 7 = 0x07
	0x73,// Mf_1
		0xBB, 0x04,// Fstp_m80fp

	// handlers_FPU_DB_high
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xBC, 0x04,// Fcmovnb_st0_sti

	// 8 = 0x08
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xBD, 0x04,// Fcmovne_st0_sti

	// 16 = 0x10
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xBE, 0x04,// Fcmovnbe_st0_sti

	// 24 = 0x18
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xBF, 0x04,// Fcmovnu_st0_sti

	// 32 = 0x20
	0xA4,// Simple
		0xC0, 0x04,// Fneni

	// 33 = 0x21
	0xA4,// Simple
		0xC2, 0x04,// Fndisi

	// 34 = 0x22
	0xA4,// Simple
		0xC4, 0x04,// Fnclex

	// 35 = 0x23
	0xA4,// Simple
		0xC6, 0x04,// Fninit

	// 36 = 0x24
	0xA4,// Simple
		0xC8, 0x04,// Fnsetpm

	// 37 = 0x25
	0x00,// Bitness
		0x0A,// Options3
			0x02,// Invalid
			0xA4,// Simple
				0xCA, 0x04,// Frstpm
			0x40,// OldFpu
		0x02,// Invalid

	// 38 = 0x26
	0x04,// Invalid2

	// 40 = 0x28
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xCB, 0x04,// Fucomi_st0_sti

	// 48 = 0x30
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xCC, 0x04,// Fcomi_st0_sti

	// 56 = 0x38
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// 60 = 0x3C
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xAF, 0x21,// Frint2
		0x80, 0x80, 0x40,// Cyrix

	// 61 = 0x3D
	0x05,// Dup
		0x03,// 3
		0x02,// Invalid

	// handlers_FPU_DC_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xCD, 0x04,// Fadd_m64fp

	// 1 = 0x01
	0x73,// Mf_1
		0xCE, 0x04,// Fmul_m64fp

	// 2 = 0x02
	0x73,// Mf_1
		0xCF, 0x04,// Fcom_m64fp

	// 3 = 0x03
	0x73,// Mf_1
		0xD0, 0x04,// Fcomp_m64fp

	// 4 = 0x04
	0x73,// Mf_1
		0xD1, 0x04,// Fsub_m64fp

	// 5 = 0x05
	0x73,// Mf_1
		0xD2, 0x04,// Fsubr_m64fp

	// 6 = 0x06
	0x73,// Mf_1
		0xD3, 0x04,// Fdiv_m64fp

	// 7 = 0x07
	0x73,// Mf_1
		0xD4, 0x04,// Fdivr_m64fp

	// handlers_FPU_DC_high
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0xB0,// STi_ST
		0xD5, 0x04,// Fadd_sti_st0

	// 1 = 0x01
	0xB0,// STi_ST
		0xD6, 0x04,// Fmul_sti_st0

	// 2 = 0x02
	0xAE,// ST_STi
		0xD7, 0x04,// Fcom_st0_sti_DCD0

	// 3 = 0x03
	0xAE,// ST_STi
		0xD8, 0x04,// Fcomp_st0_sti_DCD8

	// 4 = 0x04
	0xB0,// STi_ST
		0xD9, 0x04,// Fsubr_sti_st0

	// 5 = 0x05
	0xB0,// STi_ST
		0xDA, 0x04,// Fsub_sti_st0

	// 6 = 0x06
	0xB0,// STi_ST
		0xDB, 0x04,// Fdivr_sti_st0

	// 7 = 0x07
	0xB0,// STi_ST
		0xDC, 0x04,// Fdiv_sti_st0

	// handlers_FPU_DD_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xDD, 0x04,// Fld_m64fp

	// 1 = 0x01
	0x73,// Mf_1
		0xDE, 0x04,// Fisttp_m64int

	// 2 = 0x02
	0x73,// Mf_1
		0xDF, 0x04,// Fst_m64fp

	// 3 = 0x03
	0x73,// Mf_1
		0xE0, 0x04,// Fstp_m64fp

	// 4 = 0x04
	0x74,// Mf_2a
		0xE1, 0x04,// Frstor_m94byte

	// 5 = 0x05
	0x02,// Invalid

	// 6 = 0x06
	0x75,// Mf_2b
		0xE3, 0x04,// Fnsave_m94byte
		0xE5, 0x04,// Fnsave_m108byte

	// 7 = 0x07
	0x73,// Mf_1
		0xE7, 0x04,// Fnstsw_m2byte

	// handlers_FPU_DD_high
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0xE9, 0x04,// Ffree_sti

	// 8 = 0x08
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xEA, 0x04,// Fxch_st0_sti_DDC8

	// 16 = 0x10
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0xEB, 0x04,// Fst_sti

	// 24 = 0x18
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0xEC, 0x04,// Fstp_sti

	// 32 = 0x20
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xED, 0x04,// Fucom_st0_sti

	// 40 = 0x28
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xEE, 0x04,// Fucomp_st0_sti

	// 48 = 0x30
	0x05,// Dup
		0x0C,// 12
		0x02,// Invalid

	// 60 = 0x3C
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xB0, 0x21,// Frichop
		0x80, 0x80, 0x40,// Cyrix

	// 61 = 0x3D
	0x05,// Dup
		0x03,// 3
		0x02,// Invalid

	// handlers_FPU_DE_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xEF, 0x04,// Fiadd_m16int

	// 1 = 0x01
	0x73,// Mf_1
		0xF0, 0x04,// Fimul_m16int

	// 2 = 0x02
	0x73,// Mf_1
		0xF1, 0x04,// Ficom_m16int

	// 3 = 0x03
	0x73,// Mf_1
		0xF2, 0x04,// Ficomp_m16int

	// 4 = 0x04
	0x73,// Mf_1
		0xF3, 0x04,// Fisub_m16int

	// 5 = 0x05
	0x73,// Mf_1
		0xF4, 0x04,// Fisubr_m16int

	// 6 = 0x06
	0x73,// Mf_1
		0xF5, 0x04,// Fidiv_m16int

	// 7 = 0x07
	0x73,// Mf_1
		0xF6, 0x04,// Fidivr_m16int

	// handlers_FPU_DE_high
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0xB0,// STi_ST
			0xF7, 0x04,// Faddp_sti_st0

	// 8 = 0x08
	0x05,// Dup
		0x08,// 8
		0xB0,// STi_ST
			0xF8, 0x04,// Fmulp_sti_st0

	// 16 = 0x10
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0xF9, 0x04,// Fcomp_st0_sti_DED0

	// 24 = 0x18
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xB1, 0x21,// Cyrix_DED8
		0x80, 0x80, 0x40,// Cyrix

	// 25 = 0x19
	0xA4,// Simple
		0xFA, 0x04,// Fcompp

	// 26 = 0x1A
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xB2, 0x21,// Cyrix_DEDA
		0x80, 0x80, 0x40,// Cyrix

	// 27 = 0x1B
	0x02,// Invalid

	// 28 = 0x1C
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xB3, 0x21,// Cyrix_DEDC
		0x80, 0x80, 0x40,// Cyrix

	// 29 = 0x1D
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xB4, 0x21,// Cyrix_DEDD
		0x80, 0x80, 0x40,// Cyrix

	// 30 = 0x1E
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xB5, 0x21,// Cyrix_DEDE
		0x80, 0x80, 0x40,// Cyrix

	// 31 = 0x1F
	0x02,// Invalid

	// 32 = 0x20
	0x05,// Dup
		0x08,// 8
		0xB0,// STi_ST
			0xFB, 0x04,// Fsubrp_sti_st0

	// 40 = 0x28
	0x05,// Dup
		0x08,// 8
		0xB0,// STi_ST
			0xFC, 0x04,// Fsubp_sti_st0

	// 48 = 0x30
	0x05,// Dup
		0x08,// 8
		0xB0,// STi_ST
			0xFD, 0x04,// Fdivrp_sti_st0

	// 56 = 0x38
	0x05,// Dup
		0x08,// 8
		0xB0,// STi_ST
			0xFE, 0x04,// Fdivp_sti_st0

	// handlers_FPU_DF_low
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x73,// Mf_1
		0xFF, 0x04,// Fild_m16int

	// 1 = 0x01
	0x73,// Mf_1
		0x80, 0x05,// Fisttp_m16int

	// 2 = 0x02
	0x73,// Mf_1
		0x81, 0x05,// Fist_m16int

	// 3 = 0x03
	0x73,// Mf_1
		0x82, 0x05,// Fistp_m16int

	// 4 = 0x04
	0x73,// Mf_1
		0x83, 0x05,// Fbld_m80bcd

	// 5 = 0x05
	0x73,// Mf_1
		0x84, 0x05,// Fild_m64int

	// 6 = 0x06
	0x73,// Mf_1
		0x85, 0x05,// Fbstp_m80bcd

	// 7 = 0x07
	0x73,// Mf_1
		0x86, 0x05,// Fistp_m64int

	// handlers_FPU_DF_high
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0x87, 0x05,// Ffreep_sti

	// 8 = 0x08
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0x88, 0x05,// Fxch_st0_sti_DFC8

	// 16 = 0x10
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0x89, 0x05,// Fstp_sti_DFD0

	// 24 = 0x18
	0x05,// Dup
		0x08,// 8
		0xAF,// STi
			0x8A, 0x05,// Fstp_sti_DFD8

	// 32 = 0x20
	0x91,// Reg
		0x8B, 0x05,// Fnstsw_AX
		0x15,// AX

	// 33 = 0x21
	0x00,// Bitness
		0x0A,// Options3
			0x02,// Invalid
			0x91,// Reg
				0x8C, 0x21,// Fnstdw_AX
				0x15,// AX
			0x40,// OldFpu
		0x02,// Invalid

	// 34 = 0x22
	0x00,// Bitness
		0x0A,// Options3
			0x02,// Invalid
			0x91,// Reg
				0x8D, 0x21,// Fnstsg_AX
				0x15,// AX
			0x40,// OldFpu
		0x02,// Invalid

	// 35 = 0x23
	0x05,// Dup
		0x05,// 5
		0x02,// Invalid

	// 40 = 0x28
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0x8F, 0x05,// Fucomip_st0_sti

	// 48 = 0x30
	0x05,// Dup
		0x08,// 8
		0xAE,// ST_STi
			0x90, 0x05,// Fcomip_st0_sti

	// 56 = 0x38
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// 60 = 0x3C
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0xB6, 0x21,// Frinear
		0x80, 0x80, 0x40,// Cyrix

	// 61 = 0x3D
	0x05,// Dup
		0x03,// 3
		0x02,// Invalid

	// handlers_Grp_80
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x2E,// Eb_Ib_2
		0xCF, 0x01,// Add_rm8_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 1 = 0x01
	0x2E,// Eb_Ib_2
		0xD0, 0x01,// Or_rm8_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 2 = 0x02
	0x2E,// Eb_Ib_2
		0xD1, 0x01,// Adc_rm8_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 3 = 0x03
	0x2E,// Eb_Ib_2
		0xD2, 0x01,// Sbb_rm8_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 4 = 0x04
	0x2E,// Eb_Ib_2
		0xD3, 0x01,// And_rm8_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 5 = 0x05
	0x2E,// Eb_Ib_2
		0xD4, 0x01,// Sub_rm8_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 6 = 0x06
	0x2E,// Eb_Ib_2
		0xD5, 0x01,// Xor_rm8_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 7 = 0x07
	0x2D,// Eb_Ib_1
		0xD6, 0x01,// Cmp_rm8_imm8

	// handlers_Grp_81
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x42,// Ev_Iz_4
		0xD7, 0x01,// Add_rm16_imm16
		0x0B,// Xacquire, Xrelease, Lock

	// 1 = 0x01
	0x42,// Ev_Iz_4
		0xDA, 0x01,// Or_rm16_imm16
		0x0B,// Xacquire, Xrelease, Lock

	// 2 = 0x02
	0x42,// Ev_Iz_4
		0xDD, 0x01,// Adc_rm16_imm16
		0x0B,// Xacquire, Xrelease, Lock

	// 3 = 0x03
	0x42,// Ev_Iz_4
		0xE0, 0x01,// Sbb_rm16_imm16
		0x0B,// Xacquire, Xrelease, Lock

	// 4 = 0x04
	0x42,// Ev_Iz_4
		0xE3, 0x01,// And_rm16_imm16
		0x0B,// Xacquire, Xrelease, Lock

	// 5 = 0x05
	0x42,// Ev_Iz_4
		0xE6, 0x01,// Sub_rm16_imm16
		0x0B,// Xacquire, Xrelease, Lock

	// 6 = 0x06
	0x42,// Ev_Iz_4
		0xE9, 0x01,// Xor_rm16_imm16
		0x0B,// Xacquire, Xrelease, Lock

	// 7 = 0x07
	0x41,// Ev_Iz_3
		0xEC, 0x01,// Cmp_rm16_imm16

	// handlers_Grp_82
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x2E,// Eb_Ib_2
		0xEF, 0x01,// Add_rm8_imm8_82
		0x0B,// Xacquire, Xrelease, Lock

	// 1 = 0x01
	0x2E,// Eb_Ib_2
		0xF0, 0x01,// Or_rm8_imm8_82
		0x0B,// Xacquire, Xrelease, Lock

	// 2 = 0x02
	0x2E,// Eb_Ib_2
		0xF1, 0x01,// Adc_rm8_imm8_82
		0x0B,// Xacquire, Xrelease, Lock

	// 3 = 0x03
	0x2E,// Eb_Ib_2
		0xF2, 0x01,// Sbb_rm8_imm8_82
		0x0B,// Xacquire, Xrelease, Lock

	// 4 = 0x04
	0x2E,// Eb_Ib_2
		0xF3, 0x01,// And_rm8_imm8_82
		0x0B,// Xacquire, Xrelease, Lock

	// 5 = 0x05
	0x2E,// Eb_Ib_2
		0xF4, 0x01,// Sub_rm8_imm8_82
		0x0B,// Xacquire, Xrelease, Lock

	// 6 = 0x06
	0x2E,// Eb_Ib_2
		0xF5, 0x01,// Xor_rm8_imm8_82
		0x0B,// Xacquire, Xrelease, Lock

	// 7 = 0x07
	0x2D,// Eb_Ib_1
		0xF6, 0x01,// Cmp_rm8_imm8_82

	// handlers_Grp_83
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x3E,// Ev_Ib_4
		0xF7, 0x01,// Add_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 1 = 0x01
	0x3E,// Ev_Ib_4
		0xFA, 0x01,// Or_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 2 = 0x02
	0x3E,// Ev_Ib_4
		0xFD, 0x01,// Adc_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 3 = 0x03
	0x3E,// Ev_Ib_4
		0x80, 0x02,// Sbb_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 4 = 0x04
	0x3E,// Ev_Ib_4
		0x83, 0x02,// And_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 5 = 0x05
	0x3E,// Ev_Ib_4
		0x86, 0x02,// Sub_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 6 = 0x06
	0x3E,// Ev_Ib_4
		0x89, 0x02,// Xor_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 7 = 0x07
	0x3D,// Ev_Ib_3
		0x8C, 0x02,// Cmp_rm16_imm8

	// handlers_Grp_8F
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x85,// PushEv
		0xA8, 0x02,// Pop_rm16

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_C0
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x2D,// Eb_Ib_1
		0xE7, 0x02,// Rol_rm8_imm8

	// 1 = 0x01
	0x2D,// Eb_Ib_1
		0xE8, 0x02,// Ror_rm8_imm8

	// 2 = 0x02
	0x2D,// Eb_Ib_1
		0xE9, 0x02,// Rcl_rm8_imm8

	// 3 = 0x03
	0x2D,// Eb_Ib_1
		0xEA, 0x02,// Rcr_rm8_imm8

	// 4 = 0x04
	0x2D,// Eb_Ib_1
		0xEB, 0x02,// Shl_rm8_imm8

	// 5 = 0x05
	0x2D,// Eb_Ib_1
		0xEC, 0x02,// Shr_rm8_imm8

	// 6 = 0x06
	0x2D,// Eb_Ib_1
		0xED, 0x02,// Sal_rm8_imm8

	// 7 = 0x07
	0x2D,// Eb_Ib_1
		0xEE, 0x02,// Sar_rm8_imm8

	// handlers_Grp_C1
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x3F,// Ev_Ib2_3
		0xEF, 0x02,// Rol_rm16_imm8

	// 1 = 0x01
	0x3F,// Ev_Ib2_3
		0xF2, 0x02,// Ror_rm16_imm8

	// 2 = 0x02
	0x3F,// Ev_Ib2_3
		0xF5, 0x02,// Rcl_rm16_imm8

	// 3 = 0x03
	0x3F,// Ev_Ib2_3
		0xF8, 0x02,// Rcr_rm16_imm8

	// 4 = 0x04
	0x3F,// Ev_Ib2_3
		0xFB, 0x02,// Shl_rm16_imm8

	// 5 = 0x05
	0x3F,// Ev_Ib2_3
		0xFE, 0x02,// Shr_rm16_imm8

	// 6 = 0x06
	0x3F,// Ev_Ib2_3
		0x81, 0x03,// Sal_rm16_imm8

	// 7 = 0x07
	0x3F,// Ev_Ib2_3
		0x84, 0x03,// Sar_rm16_imm8

	// handlers_Grp_D0
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x2F,// Eb1
		0xAA, 0x03,// Rol_rm8_1

	// 1 = 0x01
	0x2F,// Eb1
		0xAB, 0x03,// Ror_rm8_1

	// 2 = 0x02
	0x2F,// Eb1
		0xAC, 0x03,// Rcl_rm8_1

	// 3 = 0x03
	0x2F,// Eb1
		0xAD, 0x03,// Rcr_rm8_1

	// 4 = 0x04
	0x2F,// Eb1
		0xAE, 0x03,// Shl_rm8_1

	// 5 = 0x05
	0x2F,// Eb1
		0xAF, 0x03,// Shr_rm8_1

	// 6 = 0x06
	0x2F,// Eb1
		0xB0, 0x03,// Sal_rm8_1

	// 7 = 0x07
	0x2F,// Eb1
		0xB1, 0x03,// Sar_rm8_1

	// handlers_Grp_D1
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x47,// Ev1
		0xB2, 0x03,// Rol_rm16_1

	// 1 = 0x01
	0x47,// Ev1
		0xB5, 0x03,// Ror_rm16_1

	// 2 = 0x02
	0x47,// Ev1
		0xB8, 0x03,// Rcl_rm16_1

	// 3 = 0x03
	0x47,// Ev1
		0xBB, 0x03,// Rcr_rm16_1

	// 4 = 0x04
	0x47,// Ev1
		0xBE, 0x03,// Shl_rm16_1

	// 5 = 0x05
	0x47,// Ev1
		0xC1, 0x03,// Shr_rm16_1

	// 6 = 0x06
	0x47,// Ev1
		0xC4, 0x03,// Sal_rm16_1

	// 7 = 0x07
	0x47,// Ev1
		0xC7, 0x03,// Sar_rm16_1

	// handlers_Grp_D2
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x2A,// Eb_CL
		0xCA, 0x03,// Rol_rm8_CL

	// 1 = 0x01
	0x2A,// Eb_CL
		0xCB, 0x03,// Ror_rm8_CL

	// 2 = 0x02
	0x2A,// Eb_CL
		0xCC, 0x03,// Rcl_rm8_CL

	// 3 = 0x03
	0x2A,// Eb_CL
		0xCD, 0x03,// Rcr_rm8_CL

	// 4 = 0x04
	0x2A,// Eb_CL
		0xCE, 0x03,// Shl_rm8_CL

	// 5 = 0x05
	0x2A,// Eb_CL
		0xCF, 0x03,// Shr_rm8_CL

	// 6 = 0x06
	0x2A,// Eb_CL
		0xD0, 0x03,// Sal_rm8_CL

	// 7 = 0x07
	0x2A,// Eb_CL
		0xD1, 0x03,// Sar_rm8_CL

	// handlers_Grp_D3
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x35,// Ev_CL
		0xD2, 0x03,// Rol_rm16_CL

	// 1 = 0x01
	0x35,// Ev_CL
		0xD5, 0x03,// Ror_rm16_CL

	// 2 = 0x02
	0x35,// Ev_CL
		0xD8, 0x03,// Rcl_rm16_CL

	// 3 = 0x03
	0x35,// Ev_CL
		0xDB, 0x03,// Rcr_rm16_CL

	// 4 = 0x04
	0x35,// Ev_CL
		0xDE, 0x03,// Shl_rm16_CL

	// 5 = 0x05
	0x35,// Ev_CL
		0xE1, 0x03,// Shr_rm16_CL

	// 6 = 0x06
	0x35,// Ev_CL
		0xE4, 0x03,// Sal_rm16_CL

	// 7 = 0x07
	0x35,// Ev_CL
		0xE7, 0x03,// Sar_rm16_CL

	// handlers_Grp_F6
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x2D,// Eb_Ib_1
		0xC7, 0x05,// Test_rm8_imm8

	// 1 = 0x01
	0x2D,// Eb_Ib_1
		0xC8, 0x05,// Test_rm8_imm8_F6r1

	// 2 = 0x02
	0x29,// Eb_2
		0xC9, 0x05,// Not_rm8
		0x0B,// Xacquire, Xrelease, Lock

	// 3 = 0x03
	0x29,// Eb_2
		0xCA, 0x05,// Neg_rm8
		0x0B,// Xacquire, Xrelease, Lock

	// 4 = 0x04
	0x28,// Eb_1
		0xCB, 0x05,// Mul_rm8

	// 5 = 0x05
	0x28,// Eb_1
		0xCC, 0x05,// Imul_rm8

	// 6 = 0x06
	0x28,// Eb_1
		0xCD, 0x05,// Div_rm8

	// 7 = 0x07
	0x28,// Eb_1
		0xCE, 0x05,// Idiv_rm8

	// handlers_Grp_F7
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x41,// Ev_Iz_3
		0xCF, 0x05,// Test_rm16_imm16

	// 1 = 0x01
	0x41,// Ev_Iz_3
		0xD2, 0x05,// Test_rm16_imm16_F7r1

	// 2 = 0x02
	0x34,// Ev_4
		0xD5, 0x05,// Not_rm16
		0x0B,// Xacquire, Xrelease, Lock

	// 3 = 0x03
	0x34,// Ev_4
		0xD8, 0x05,// Neg_rm16
		0x0B,// Xacquire, Xrelease, Lock

	// 4 = 0x04
	0x32,// Ev_3a
		0xDB, 0x05,// Mul_rm16

	// 5 = 0x05
	0x32,// Ev_3a
		0xDE, 0x05,// Imul_rm16

	// 6 = 0x06
	0x32,// Ev_3a
		0xE1, 0x05,// Div_rm16

	// 7 = 0x07
	0x32,// Ev_3a
		0xE4, 0x05,// Idiv_rm16

	// handlers_Grp_FE
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x29,// Eb_2
		0xED, 0x05,// Inc_rm8
		0x0B,// Xacquire, Xrelease, Lock

	// 1 = 0x01
	0x29,// Eb_2
		0xEE, 0x05,// Dec_rm8
		0x0B,// Xacquire, Xrelease, Lock

	// 2 = 0x02
	0x05,// Dup
		0x06,// 6
		0x02,// Invalid

	// handlers_Grp_FF
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x34,// Ev_4
		0xEF, 0x05,// Inc_rm16
		0x0B,// Xacquire, Xrelease, Lock

	// 1 = 0x01
	0x34,// Ev_4
		0xF2, 0x05,// Dec_rm16
		0x0B,// Xacquire, Xrelease, Lock

	// 2 = 0x02
	0x48,// Evj
		0xF5, 0x05,// Call_rm16

	// 3 = 0x03
	0x31,// Ep
		0xF8, 0x05,// Call_m1616

	// 4 = 0x04
	0x48,// Evj
		0xFB, 0x05,// Jmp_rm16

	// 5 = 0x05
	0x31,// Ep
		0xFE, 0x05,// Jmp_m1616

	// 6 = 0x06
	0x85,// PushEv
		0x81, 0x06,// Push_rm16

	// 7 = 0x07
	0x02,// Invalid

	// handlers_Grp_0F00
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x49,// Evw
		0x84, 0x06,// Sldt_rm16

	// 1 = 0x01
	0x49,// Evw
		0x87, 0x06,// Str_rm16

	// 2 = 0x02
	0x4A,// Ew
		0x8A, 0x06,// Lldt_rm16

	// 3 = 0x03
	0x4A,// Ew
		0x8D, 0x06,// Ltr_rm16

	// 4 = 0x04
	0x4A,// Ew
		0x90, 0x06,// Verr_rm16

	// 5 = 0x05
	0x4A,// Ew
		0x93, 0x06,// Verw_rm16

	// 6 = 0x06
	0x0C,// Options_DontReadModRM
		0x11,// MandatoryPrefix
			0x02,// Invalid
			0x02,// Invalid
			0x02,// Invalid
			0x01,// Bitness_DontReadModRM
				0x02,// Invalid
				0x49,// Evw
					0xDE, 0x21,// Lkgs_rm16
		0x01,// Bitness_DontReadModRM
			0x33,// Ev_3b
				0x96, 0x06,// Jmpe_rm16
			0x11,// MandatoryPrefix
				0x02,// Invalid
				0x02,// Invalid
				0x02,// Invalid
				0x01,// Bitness_DontReadModRM
					0x02,// Invalid
					0x49,// Evw
						0xDE, 0x21,// Lkgs_rm16
		0x80, 0x20,// Jmpe

	// 7 = 0x07
	0x02,// Invalid

	// handlers_Grp_0F01_lo
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0x02,// Invalid
		0x78,// Ms
			0x98, 0x06,// Sgdt_m1632_16

	// 1 = 0x01
	0x09,// RM
		0x02,// Invalid
		0x78,// Ms
			0x9B, 0x06,// Sidt_m1632_16

	// 2 = 0x02
	0x09,// RM
		0x02,// Invalid
		0x78,// Ms
			0x9E, 0x06,// Lgdt_m1632_16

	// 3 = 0x03
	0x09,// RM
		0x02,// Invalid
		0x78,// Ms
			0xA1, 0x06,// Lidt_m1632_16

	// 4 = 0x04
	0x49,// Evw
		0xA4, 0x06,// Smsw_rm16

	// 5 = 0x05
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x02,// Invalid
		0x6E,// M_1
			0xA7, 0x06,// Rstorssp_m64
		0x02,// Invalid

	// 6 = 0x06
	0x49,// Evw
		0xA8, 0x06,// Lmsw_rm16

	// 7 = 0x07
	0x6E,// M_1
		0xAB, 0x06,// Invlpg_m

	// handlers_Grp_0F01_hi
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xAC, 0x06,// Enclv
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 1 = 0x01
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xAD, 0x06,// Vmcall
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 2 = 0x02
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xAE, 0x06,// Vmlaunch
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 3 = 0x03
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xAF, 0x06,// Vmresume
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 4 = 0x04
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xB0, 0x06,// Vmxoff
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 5 = 0x05
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xB1, 0x06,// Pconfig
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 6 = 0x06
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xE2, 0x25,// Wrmsrns
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xE3, 0x25,// Wrmsrlist
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xE4, 0x25,// Rdmsrlist

	// 7 = 0x07
	0x14,// MandatoryPrefix_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xB1, 0x26,// Pbndkb
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 8 = 0x08
	0x14,// MandatoryPrefix_NoModRM
		0xAB,// Simple5
			0xB2, 0x06,// Monitorw
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 9 = 0x09
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xB5, 0x06,// Mwait
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 10 = 0x0A
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xB6, 0x06,// Clac
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xE1, 0x21,// Eretu
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xE2, 0x21,// Erets

	// 11 = 0x0B
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xB7, 0x06,// Stac
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 12 = 0x0C
	0x14,// MandatoryPrefix_NoModRM
		0x03,// Invalid_NoModRM
		0xA4,// Simple
			0xB7, 0x21,// Tdcall
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 13 = 0x0D
	0x14,// MandatoryPrefix_NoModRM
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xB8, 0x21,// Seamret
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 14 = 0x0E
	0x14,// MandatoryPrefix_NoModRM
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xB9, 0x21,// Seamops
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 15 = 0x0F
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xB8, 0x06,// Encls
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xBA, 0x21,// Seamcall
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 16 = 0x10
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xB9, 0x06,// Xgetbv
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 17 = 0x11
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xBA, 0x06,// Xsetbv
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 18 = 0x12
	0x05,// Dup
		0x02,// 2
		0x06,// Null

	// 20 = 0x14
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xBB, 0x06,// Vmfunc
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 21 = 0x15
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xBC, 0x06,// Xend
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 22 = 0x16
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xBD, 0x06,// Xtest
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 23 = 0x17
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xBE, 0x06,// Enclu
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 24 = 0x18
	0xAB,// Simple5
		0xBF, 0x06,// Vmrunw

	// 25 = 0x19
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xC2, 0x06,// Vmmcall
		0xA4,// Simple
			0xC2, 0x06,// Vmmcall
		0xA4,// Simple
			0xFE, 0x20,// Vmgexit
		0xA4,// Simple
			0xC9, 0x21,// Vmgexit_F2

	// 26 = 0x1A
	0xAB,// Simple5
		0xC3, 0x06,// Vmloadw

	// 27 = 0x1B
	0xAB,// Simple5
		0xC6, 0x06,// Vmsavew

	// 28 = 0x1C
	0xA4,// Simple
		0xC9, 0x06,// Stgi

	// 29 = 0x1D
	0xA4,// Simple
		0xCA, 0x06,// Clgi

	// 30 = 0x1E
	0xA4,// Simple
		0xCB, 0x06,// Skinit

	// 31 = 0x1F
	0xAB,// Simple5
		0xCC, 0x06,// Invlpgaw

	// 32 = 0x20
	0x05,// Dup
		0x08,// 8
		0x06,// Null

	// 40 = 0x28
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0xF1, 0x20,// Serialize
		0x02,// Invalid
		0xA5,// Simple_ModRM
			0xCF, 0x06,// Setssbsy
		0xA5,// Simple_ModRM
			0xF2, 0x20,// Xsusldtrk

	// 41 = 0x29
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid
		0xA5,// Simple_ModRM
			0xF3, 0x20,// Xresldtrk

	// 42 = 0x2A
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x02,// Invalid
		0xA5,// Simple_ModRM
			0xD0, 0x06,// Saveprevssp
		0x02,// Invalid

	// 43 = 0x2B
	0x06,// Null

	// 44 = 0x2C
	0x14,// MandatoryPrefix_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xCA, 0x21,// Uiret
		0x03,// Invalid_NoModRM

	// 45 = 0x2D
	0x14,// MandatoryPrefix_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xCB, 0x21,// Testui
		0x03,// Invalid_NoModRM

	// 46 = 0x2E
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xD1, 0x06,// Rdpkru
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xCC, 0x21,// Clui
		0x03,// Invalid_NoModRM

	// 47 = 0x2F
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xD2, 0x06,// Wrpkru
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xCD, 0x21,// Stui
		0x03,// Invalid_NoModRM

	// 48 = 0x30
	0x05,// Dup
		0x08,// 8
		0x06,// Null

	// 56 = 0x38
	0x00,// Bitness
		0x02,// Invalid
		0xA4,// Simple
			0xD3, 0x06,// Swapgs

	// 57 = 0x39
	0xA4,// Simple
		0xD4, 0x06,// Rdtscp

	// 58 = 0x3A
	0x14,// MandatoryPrefix_NoModRM
		0xAB,// Simple5
			0xD5, 0x06,// Monitorxw
		0x03,// Invalid_NoModRM
		0xA4,// Simple
			0xD8, 0x06,// Mcommit
		0x03,// Invalid_NoModRM

	// 59 = 0x3B
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xD9, 0x06,// Mwaitx
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 60 = 0x3C
	0xAB,// Simple5
		0xDA, 0x06,// Clzerow

	// 61 = 0x3D
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xDD, 0x06,// Rdpru
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xE5, 0x25,// Rmpquery
		0x03,// Invalid_NoModRM

	// 62 = 0x3E
	0x14,// MandatoryPrefix_NoModRM
		0xAB,// Simple5
			0xF4, 0x20,// Invlpgbw
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xEB, 0x20,// Rmpadjust
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xEC, 0x20,// Rmpupdate

	// 63 = 0x3F
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xF7, 0x20,// Tlbsync
		0x03,// Invalid_NoModRM
		0x00,// Bitness
			0x03,// Invalid_NoModRM
			0xA4,// Simple
				0xED, 0x20,// Psmash
		0xAB,// Simple5
			0xEE, 0x20,// Pvalidatew

	// handlers_Grp_0F36_Cyrix
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x13,// Ev_REXW_1a
		0x8E, 0x21,// Rdshr_rm32
		0x03,// 0x3

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_0F37_Cyrix
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x13,// Ev_REXW_1a
		0x8F, 0x21,// Wrshr_rm32
		0x03,// 0x3

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_0F7A_Cyrix
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0x02,// Invalid
		0x13,// Ev_REXW_1a
			0x95, 0x21,// Svldt_m80
			0x02,// 0x2

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_0F7B_Cyrix
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0x02,// Invalid
		0x13,// Ev_REXW_1a
			0x96, 0x21,// Rsldt_m80
			0x02,// 0x2

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_0F7C_Cyrix
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0x02,// Invalid
		0x13,// Ev_REXW_1a
			0x97, 0x21,// Svts_m80
			0x02,// 0x2

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_0F7D_Cyrix
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0x02,// Invalid
		0x13,// Ev_REXW_1a
			0x98, 0x21,// Rsts_m80
			0x02,// 0x2

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_0FA6
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xD6,// Simple5_a32
				0xA6, 0x0F,// Montmul_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 1 = 0x01
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xA9, 0x0F,// Xsha1_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 2 = 0x02
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xAC, 0x0F,// Xsha256_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 3 = 0x03
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xDE, 0x25,// Xsha512_alt_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 4 = 0x04
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xD8, 0x25,// Xsha512_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 5 = 0x05
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xD8, 0x21,// Ccs_hash_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 6 = 0x06
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xD2, 0x25,// Via_undoc_F30FA6F0_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 7 = 0x07
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xD5, 0x25,// Via_undoc_F30FA6F8_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// handlers_Grp_0FA7
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0xAB,// Simple5
			0xB1, 0x0F,// Xstore_16
		0x02,// Invalid

	// 1 = 0x01
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xB4, 0x0F,// Xcryptecb_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 2 = 0x02
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xB7, 0x0F,// Xcryptcbc_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 3 = 0x03
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xBA, 0x0F,// Xcryptctr_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 4 = 0x04
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xBD, 0x0F,// Xcryptcfb_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 5 = 0x05
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xC0, 0x0F,// Xcryptofb_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 6 = 0x06
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xDB, 0x21,// Ccs_encrypt_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// 7 = 0x07
	0x09,// RM
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0xAB,// Simple5
				0xDB, 0x25,// Xstore_alt_16
			0x02,// Invalid
			0x00,// 0x0
		0x02,// Invalid

	// handlers_Grp_0FBA
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// 4 = 0x04
	0x3F,// Ev_Ib2_3
		0xB7, 0x10,// Bt_rm16_imm8

	// 5 = 0x05
	0x40,// Ev_Ib2_4
		0xBA, 0x10,// Bts_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 6 = 0x06
	0x40,// Ev_Ib2_4
		0xBD, 0x10,// Btr_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// 7 = 0x07
	0x40,// Ev_Ib2_4
		0xC0, 0x10,// Btc_rm16_imm8
		0x0B,// Xacquire, Xrelease, Lock

	// handlers_Grp_0FC7
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x02,// Invalid

	// 1 = 0x01
	0x71,// M_REXW_4
		0x8C, 0x11,// Cmpxchg8b_m64
		0x0B,// Xacquire, Xrelease, Lock
		0x08,// Lock

	// 2 = 0x02
	0x02,// Invalid

	// 3 = 0x03
	0x11,// MandatoryPrefix
		0x70,// M_REXW_2
			0x8E, 0x11,// Xrstors_mem
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 4 = 0x04
	0x11,// MandatoryPrefix
		0x70,// M_REXW_2
			0x90, 0x11,// Xsavec_mem
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 5 = 0x05
	0x11,// MandatoryPrefix
		0x09,// RM
			0x02,// Invalid
			0x44,// Ev_REXW
				0x92, 0x11,// Xsaves_mem
				0x02,// 0x2
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 6 = 0x06
	0x15,// MandatoryPrefix3
		0xA1,// Rv
			0x97, 0x11,// Rdrand_r16
		0x6E,// M_1
			0x94, 0x11,// Vmptrld_m64
		0xA1,// Rv
			0x97, 0x11,// Rdrand_r16
		0x6E,// M_1
			0x95, 0x11,// Vmclear_m64
		0x01,// Bitness_DontReadModRM
			0x02,// Invalid
			0xCC,// Rq
				0xCE, 0x21,// Senduipi_r64
		0x6E,// M_1
			0x96, 0x11,// Vmxon_m64
		0x02,// Invalid
		0x02,// Invalid
		0x05,// HandlerReg, Handler66Reg

	// 7 = 0x07
	0x15,// MandatoryPrefix3
		0xA1,// Rv
			0x9B, 0x11,// Rdseed_r16
		0x6E,// M_1
			0x9A, 0x11,// Vmptrst_m64
		0xA1,// Rv
			0x9B, 0x11,// Rdseed_r16
		0x02,// Invalid
		0xA2,// Rv_32_64
			0x9E, 0x11,// Rdpid_r32
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid
		0x05,// HandlerReg, Handler66Reg

	// handlers_Grp_C6_lo
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x2E,// Eb_Ib_2
		0x91, 0x03,// Mov_rm8_imm8
		0x06,// Xrelease, XacquireXreleaseNoLock

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_C6_hi
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x38,// 56
		0x06,// Null

	// 56 = 0x38
	0x65,// Ib3
		0x92, 0x03,// Xabort_imm8

	// 57 = 0x39
	0x05,// Dup
		0x07,// 7
		0x06,// Null

	// handlers_Grp_C7_lo
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x42,// Ev_Iz_4
		0x93, 0x03,// Mov_rm16_imm16
		0x06,// Xrelease, XacquireXreleaseNoLock

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_C7_hi
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x38,// 56
		0x06,// Null

	// 56 = 0x38
	0x6C,// Jx
		0x96, 0x03,// Xbegin_rel16
		0x97, 0x03,// Xbegin_rel32

	// 57 = 0x39
	0x05,// Dup
		0x07,// 7
		0x06,// Null

	// handlers_Grp_0F71
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x04,// Invalid2

	// 2 = 0x02
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0xDF, 0x0C,// Psrlw_mm_imm8
		0x9F,// RIb
			0xE0, 0x0C,// Psrlw_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 3 = 0x03
	0x02,// Invalid

	// 4 = 0x04
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0xE6, 0x0C,// Psraw_mm_imm8
		0x9F,// RIb
			0xE7, 0x0C,// Psraw_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 5 = 0x05
	0x02,// Invalid

	// 6 = 0x06
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0xED, 0x0C,// Psllw_mm_imm8
		0x9F,// RIb
			0xEE, 0x0C,// Psllw_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 7 = 0x07
	0x02,// Invalid

	// handlers_Grp_0F72
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x04,// Invalid2

	// 2 = 0x02
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0x80, 0x0D,// Psrld_mm_imm8
		0x9F,// RIb
			0x81, 0x0D,// Psrld_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 3 = 0x03
	0x02,// Invalid

	// 4 = 0x04
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0x87, 0x0D,// Psrad_mm_imm8
		0x9F,// RIb
			0x88, 0x0D,// Psrad_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 5 = 0x05
	0x02,// Invalid

	// 6 = 0x06
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0x91, 0x0D,// Pslld_mm_imm8
		0x9F,// RIb
			0x92, 0x0D,// Pslld_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 7 = 0x07
	0x02,// Invalid

	// handlers_Grp_0F73
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x04,// Invalid2

	// 2 = 0x02
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0x98, 0x0D,// Psrlq_mm_imm8
		0x9F,// RIb
			0x99, 0x0D,// Psrlq_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 3 = 0x03
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x9F,// RIb
			0x9F, 0x0D,// Psrldq_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 4 = 0x04
	0x04,// Invalid2

	// 6 = 0x06
	0x11,// MandatoryPrefix
		0x7C,// NIb
			0xA5, 0x0D,// Psllq_mm_imm8
		0x9F,// RIb
			0xA6, 0x0D,// Psllq_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 7 = 0x07
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x9F,// RIb
			0xAC, 0x0D,// Pslldq_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// handlers_Grp_0FAE_lo
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x11,// MandatoryPrefix
		0x6F,// M_2
			0xD8, 0x0F,// Fxsave_m512byte
		0x02,// Invalid
		0x01,// Bitness_DontReadModRM
			0x02,// Invalid
			0x09,// RM
				0x44,// Ev_REXW
					0xDA, 0x0F,// Rdfsbase_r32
					0x01,// 0x1
				0x02,// Invalid
		0x02,// Invalid

	// 1 = 0x01
	0x11,// MandatoryPrefix
		0x6F,// M_2
			0xDC, 0x0F,// Fxrstor_m512byte
		0x02,// Invalid
		0x01,// Bitness_DontReadModRM
			0x02,// Invalid
			0x09,// RM
				0x44,// Ev_REXW
					0xDE, 0x0F,// Rdgsbase_r32
					0x01,// 0x1
				0x02,// Invalid
		0x02,// Invalid

	// 2 = 0x02
	0x11,// MandatoryPrefix
		0x6E,// M_1
			0xE0, 0x0F,// Ldmxcsr_m32
		0x02,// Invalid
		0x01,// Bitness_DontReadModRM
			0x02,// Invalid
			0x09,// RM
				0x44,// Ev_REXW
					0xE1, 0x0F,// Wrfsbase_r32
					0x01,// 0x1
				0x02,// Invalid
		0x02,// Invalid

	// 3 = 0x03
	0x11,// MandatoryPrefix
		0x6E,// M_1
			0xE4, 0x0F,// Stmxcsr_m32
		0x02,// Invalid
		0x01,// Bitness_DontReadModRM
			0x02,// Invalid
			0x09,// RM
				0x44,// Ev_REXW
					0xE5, 0x0F,// Wrgsbase_r32
					0x01,// 0x1
				0x02,// Invalid
		0x02,// Invalid

	// 4 = 0x04
	0x11,// MandatoryPrefix
		0x6F,// M_2
			0xE8, 0x0F,// Xsave_mem
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEA, 0x0F,// Ptwrite_rm32
			0x07,// 0x7
		0x02,// Invalid

	// 5 = 0x05
	0x11,// MandatoryPrefix
		0x6F,// M_2
			0xEC, 0x0F,// Xrstor_mem
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 6 = 0x06
	0x11,// MandatoryPrefix
		0x6F,// M_2
			0xF0, 0x0F,// Xsaveopt_mem
		0x6E,// M_1
			0xF2, 0x0F,// Clwb_m8
		0x6E,// M_1
			0xF5, 0x0F,// Clrssbsy_m64
		0x02,// Invalid

	// 7 = 0x07
	0x11,// MandatoryPrefix
		0x6E,// M_1
			0xFB, 0x0F,// Clflush_m8
		0x6E,// M_1
			0xFC, 0x0F,// Clflushopt_m8
		0x02,// Invalid
		0x02,// Invalid

	// handlers_Grp_0FAE_hi
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x28,// 40
		0x06,// Null

	// 40 = 0x28
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0xFD, 0x0F,// Lfence
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 41 = 0x29
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0xFE, 0x0F,// Lfence_E9
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 42 = 0x2A
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0xFF, 0x0F,// Lfence_EA
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 43 = 0x2B
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x80, 0x10,// Lfence_EB
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 44 = 0x2C
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x81, 0x10,// Lfence_EC
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 45 = 0x2D
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x82, 0x10,// Lfence_ED
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 46 = 0x2E
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x83, 0x10,// Lfence_EE
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 47 = 0x2F
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x84, 0x10,// Lfence_EF
		0x02,// Invalid
		0x44,// Ev_REXW
			0xEE, 0x0F,// Incsspd_r32
			0x01,// 0x1
		0x02,// Invalid

	// 48 = 0x30
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x85, 0x10,// Mfence
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 49 = 0x31
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x86, 0x10,// Mfence_F1
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 50 = 0x32
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x87, 0x10,// Mfence_F2
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 51 = 0x33
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x88, 0x10,// Mfence_F3
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 52 = 0x34
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x89, 0x10,// Mfence_F4
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 53 = 0x35
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x8A, 0x10,// Mfence_F5
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 54 = 0x36
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x8B, 0x10,// Mfence_F6
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 55 = 0x37
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x8C, 0x10,// Mfence_F7
		0x44,// Ev_REXW
			0xF3, 0x0F,// Tpause_r32
			0x01,// 0x1
		0xAC,// Simple5_ModRM_as
			0xF6, 0x0F,// Umonitor_r16
		0x44,// Ev_REXW
			0xF9, 0x0F,// Umwait_r32
			0x01,// 0x1

	// 56 = 0x38
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x8D, 0x10,// Sfence
		0x0C,// Options_DontReadModRM
			0x02,// Invalid
			0xA5,// Simple_ModRM
				0x95, 0x10,// Pcommit
			0x80, 0x01,// Pcommit
		0x02,// Invalid
		0x02,// Invalid

	// 57 = 0x39
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x8E, 0x10,// Sfence_F9
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 58 = 0x3A
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x8F, 0x10,// Sfence_FA
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 59 = 0x3B
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x90, 0x10,// Sfence_FB
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 60 = 0x3C
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x91, 0x10,// Sfence_FC
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 61 = 0x3D
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x92, 0x10,// Sfence_FD
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 62 = 0x3E
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x93, 0x10,// Sfence_FE
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 63 = 0x3F
	0x11,// MandatoryPrefix
		0xA5,// Simple_ModRM
			0x94, 0x10,// Sfence_FF
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// reservedNop_0F0D
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0xF0, 0x06,// Reservednop_rm16_r16_0F0D

	// reservedNop_0F18
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0xF1, 0x07,// Reservednop_rm16_r16_0F18

	// reservedNop_0F19
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0xF4, 0x07,// Reservednop_rm16_r16_0F19

	// reservedNop_0F1A
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0xF7, 0x07,// Reservednop_rm16_r16_0F1A

	// reservedNop_0F1B
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0xFA, 0x07,// Reservednop_rm16_r16_0F1B

	// reservedNop_0F1C
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0xFD, 0x07,// Reservednop_rm16_r16_0F1C

	// reservedNop_0F1D
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0x80, 0x08,// Reservednop_rm16_r16_0F1D

	// reservedNop_0F1E
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0x83, 0x08,// Reservednop_rm16_r16_0F1E

	// reservedNop_0F1F
	0x00,// HandlerReference
	0x37,// Ev_Gv_3a
		0x86, 0x08,// Reservednop_rm16_r16_0F1F

	// handlers_Grp_0F0D_mem
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x6E,// M_1
		0xF3, 0x06,// Prefetch_m8

	// 1 = 0x01
	0x6E,// M_1
		0xF4, 0x06,// Prefetchw_m8

	// 2 = 0x02
	0x6E,// M_1
		0xF5, 0x06,// Prefetchwt1_m8

	// 3 = 0x03
	0x6E,// M_1
		0xF8, 0x20,// Prefetchreserved3_m8

	// 4 = 0x04
	0x6E,// M_1
		0xF9, 0x20,// Prefetchreserved4_m8

	// 5 = 0x05
	0x6E,// M_1
		0xFA, 0x20,// Prefetchreserved5_m8

	// 6 = 0x06
	0x6E,// M_1
		0xFB, 0x20,// Prefetchreserved6_m8

	// 7 = 0x07
	0x6E,// M_1
		0xFC, 0x20,// Prefetchreserved7_m8

	// grp0F0D
	0x00,// HandlerReference
	0x09,// RM
		0x07,// HandlerReference
			0x35,// 0x35 = reservedNop_0F0D
		0x0E,// Group
			0x08,// ArrayReference
				0x3E,// 0x3E = handlers_Grp_0F0D_mem

	// handlers_Grp_0F18_mem
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x6E,// M_1
		0x89, 0x08,// Prefetchnta_m8

	// 1 = 0x01
	0x6E,// M_1
		0x8A, 0x08,// Prefetcht0_m8

	// 2 = 0x02
	0x6E,// M_1
		0x8B, 0x08,// Prefetcht1_m8

	// 3 = 0x03
	0x6E,// M_1
		0x8C, 0x08,// Prefetcht2_m8

	// 4 = 0x04
	0x05,// Dup
		0x02,// 2
		0x07,// HandlerReference
			0x36,// 0x36 = reservedNop_0F18

	// 6 = 0x06
	0x6E,// M_1
		0xE6, 0x25,// Prefetchit1_m8

	// 7 = 0x07
	0x6E,// M_1
		0xE7, 0x25,// Prefetchit0_m8

	// grp0F18
	0x00,// HandlerReference
	0x9E,// Reservednop
		0x07,// HandlerReference
			0x36,// 0x36 = reservedNop_0F18
		0x09,// RM
			0x07,// HandlerReference
				0x36,// 0x36 = reservedNop_0F18
			0x0E,// Group
				0x08,// ArrayReference
					0x40,// 0x40 = handlers_Grp_0F18_mem

	// handlers_Grp_0F1C_mem
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x12,// MandatoryPrefix4
		0x6E,// M_1
			0x9B, 0x08,// Cldemote_m8
		0x07,// HandlerReference
			0x3A,// 0x3A = reservedNop_0F1C
		0x07,// HandlerReference
			0x3A,// 0x3A = reservedNop_0F1C
		0x07,// HandlerReference
			0x3A,// 0x3A = reservedNop_0F1C
		0x00,// 0x0

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x07,// HandlerReference
			0x3A,// 0x3A = reservedNop_0F1C

	// grp0F1C
	0x00,// HandlerReference
	0x9E,// Reservednop
		0x07,// HandlerReference
			0x3A,// 0x3A = reservedNop_0F1C
		0x09,// RM
			0x07,// HandlerReference
				0x3A,// 0x3A = reservedNop_0F1C
			0x0E,// Group
				0x08,// ArrayReference
					0x42,// 0x42 = handlers_Grp_0F1C_mem

	// handlers_Grp_0F1E_reg_lo
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E

	// grp0F1E_1
	0x00,// HandlerReference
	0x11,// MandatoryPrefix
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E
		0x09,// RM
			0x44,// Ev_REXW
				0x9C, 0x08,// Rdsspd_r32
				0x01,// 0x1
			0x07,// HandlerReference
				0x3C,// 0x3C = reservedNop_0F1E
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E

	// handlers_Grp_0F1E_reg_hi
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0x06,// Null

	// 8 = 0x08
	0x05,// Dup
		0x08,// 8
		0x07,// HandlerReference
			0x45,// 0x45 = grp0F1E_1

	// 16 = 0x10
	0x05,// Dup
		0x2A,// 42
		0x06,// Null

	// 58 = 0x3A
	0x11,// MandatoryPrefix
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E
		0xA5,// Simple_ModRM
			0x9E, 0x08,// Endbr64
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E

	// 59 = 0x3B
	0x11,// MandatoryPrefix
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E
		0xA5,// Simple_ModRM
			0x9F, 0x08,// Endbr32
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E

	// 60 = 0x3C
	0x05,// Dup
		0x04,// 4
		0x06,// Null

	// grp0F1E
	0x00,// HandlerReference
	0x9E,// Reservednop
		0x07,// HandlerReference
			0x3C,// 0x3C = reservedNop_0F1E
		0x09,// RM
			0x0F,// Group8x64
				0x08,// ArrayReference
					0x44,// 0x44 = handlers_Grp_0F1E_reg_lo
				0x08,// ArrayReference
					0x46,// 0x46 = handlers_Grp_0F1E_reg_hi
			0x07,// HandlerReference
				0x3C,// 0x3C = reservedNop_0F1E

	// handlers_Grp_0F1F
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x32,// Ev_3a
		0xA0, 0x08,// Nop_rm16

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x07,// HandlerReference
			0x3D,// 0x3D = reservedNop_0F1F

	// grp0F1F
	0x00,// HandlerReference
	0x9E,// Reservednop
		0x07,// HandlerReference
			0x3D,// 0x3D = reservedNop_0F1F
		0x0E,// Group
			0x08,// ArrayReference
				0x48,// 0x48 = handlers_Grp_0F1F

	// handlers_Grp_660F78
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0xA0,// RIbIb
		0xD2, 0x0D,// Extrq_xmm_imm8_imm8

	// 1 = 0x01
	0x05,// Dup
		0x07,// 7
		0x02,// Invalid

	// handlers_Grp_F30F38D8
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x09,// RM
		0x02,// Invalid
		0x6E,// M_1
			0xBB, 0x21,// Aesencwide128kl_m384

	// 1 = 0x01
	0x09,// RM
		0x02,// Invalid
		0x6E,// M_1
			0xBC, 0x21,// Aesdecwide128kl_m384

	// 2 = 0x02
	0x09,// RM
		0x02,// Invalid
		0x6E,// M_1
			0xBD, 0x21,// Aesencwide256kl_m512

	// 3 = 0x03
	0x09,// RM
		0x02,// Invalid
		0x6E,// M_1
			0xBE, 0x21,// Aesdecwide256kl_m512

	// 4 = 0x04
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// handlers_Grp_0F3AF0_lo
	0x01,// ArrayReference
	0x08,// 0x8
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0x02,// Invalid

	// handlers_Grp_0F3AF0_hi
	0x01,// ArrayReference
	0x40,// 0x40
	// 0 = 0x00
	0x14,// MandatoryPrefix_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x64,// Ib
			0xCF, 0x21,// Hreset_imm8
		0x03,// Invalid_NoModRM

	// 1 = 0x01
	0x05,// Dup
		0x3F,// 63
		0x06,// Null

	// Handlers_0F38
	0x01,// ArrayReference
	0x80, 0x02,// 0x100
	// 0 = 0x00
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x82, 0x14,// Pshufb_mm_mmm64
		0xB7,// VW_2
			0x83, 0x14,// Pshufb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 1 = 0x01
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x89, 0x14,// Phaddw_mm_mmm64
		0xB7,// VW_2
			0x8A, 0x14,// Phaddw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 2 = 0x02
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x8D, 0x14,// Phaddd_mm_mmm64
		0xB7,// VW_2
			0x8E, 0x14,// Phaddd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 3 = 0x03
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x91, 0x14,// Phaddsw_mm_mmm64
		0xB7,// VW_2
			0x92, 0x14,// Phaddsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 4 = 0x04
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x95, 0x14,// Pmaddubsw_mm_mmm64
		0xB7,// VW_2
			0x96, 0x14,// Pmaddubsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 5 = 0x05
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x9C, 0x14,// Phsubw_mm_mmm64
		0xB7,// VW_2
			0x9D, 0x14,// Phsubw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 6 = 0x06
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xA0, 0x14,// Phsubd_mm_mmm64
		0xB7,// VW_2
			0xA1, 0x14,// Phsubd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 7 = 0x07
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xA4, 0x14,// Phsubsw_mm_mmm64
		0xB7,// VW_2
			0xA5, 0x14,// Phsubsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 8 = 0x08
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xA8, 0x14,// Psignb_mm_mmm64
		0xB7,// VW_2
			0xA9, 0x14,// Psignb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 9 = 0x09
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xAC, 0x14,// Psignw_mm_mmm64
		0xB7,// VW_2
			0xAD, 0x14,// Psignw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 10 = 0x0A
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB0, 0x14,// Psignd_mm_mmm64
		0xB7,// VW_2
			0xB1, 0x14,// Psignd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 11 = 0x0B
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB4, 0x14,// Pmulhrsw_mm_mmm64
		0xB7,// VW_2
			0xB5, 0x14,// Pmulhrsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 12 = 0x0C
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// 16 = 0x10
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC9, 0x14,// Pblendvb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 17 = 0x11
	0x05,// Dup
		0x03,// 3
		0x02,// Invalid

	// 20 = 0x14
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xE4, 0x14,// Blendvps_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 21 = 0x15
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xEE, 0x14,// Blendvpd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 22 = 0x16
	0x02,// Invalid

	// 23 = 0x17
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xFD, 0x14,// Ptest_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 24 = 0x18
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// 28 = 0x1C
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x91, 0x15,// Pabsb_mm_mmm64
		0xB7,// VW_2
			0x92, 0x15,// Pabsb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 29 = 0x1D
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x98, 0x15,// Pabsw_mm_mmm64
		0xB7,// VW_2
			0x99, 0x15,// Pabsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 30 = 0x1E
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x9F, 0x15,// Pabsd_mm_mmm64
		0xB7,// VW_2
			0xA0, 0x15,// Pabsd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 31 = 0x1F
	0x02,// Invalid

	// 32 = 0x20
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xA9, 0x15,// Pmovsxbw_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 33 = 0x21
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xB2, 0x15,// Pmovsxbd_xmm_xmmm32
		0x02,// Invalid
		0x02,// Invalid

	// 34 = 0x22
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xBB, 0x15,// Pmovsxbq_xmm_xmmm16
		0x02,// Invalid
		0x02,// Invalid

	// 35 = 0x23
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC4, 0x15,// Pmovsxwd_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 36 = 0x24
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xCD, 0x15,// Pmovsxwq_xmm_xmmm32
		0x02,// Invalid
		0x02,// Invalid

	// 37 = 0x25
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xD6, 0x15,// Pmovsxdq_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 38 = 0x26
	0x04,// Invalid2

	// 40 = 0x28
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xF7, 0x15,// Pmuldq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 41 = 0x29
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0x83, 0x16,// Pcmpeqq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 42 = 0x2A
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB3,// VM
			0x8F, 0x16,// Movntdqa_xmm_m128
		0x02,// Invalid
		0x02,// Invalid

	// 43 = 0x2B
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0x98, 0x16,// Packusdw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 44 = 0x2C
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// 48 = 0x30
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xAE, 0x16,// Pmovzxbw_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 49 = 0x31
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xB7, 0x16,// Pmovzxbd_xmm_xmmm32
		0x02,// Invalid
		0x02,// Invalid

	// 50 = 0x32
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC0, 0x16,// Pmovzxbq_xmm_xmmm16
		0x02,// Invalid
		0x02,// Invalid

	// 51 = 0x33
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC9, 0x16,// Pmovzxwd_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 52 = 0x34
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xD2, 0x16,// Pmovzxwq_xmm_xmmm32
		0x02,// Invalid
		0x02,// Invalid

	// 53 = 0x35
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xDB, 0x16,// Pmovzxdq_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 54 = 0x36
	0x02,// Invalid

	// 55 = 0x37
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xE9, 0x16,// Pcmpgtq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 56 = 0x38
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xEF, 0x16,// Pminsb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 57 = 0x39
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xFB, 0x16,// Pminsd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 58 = 0x3A
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0x8A, 0x17,// Pminuw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 59 = 0x3B
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0x93, 0x17,// Pminud_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 60 = 0x3C
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0x9C, 0x17,// Pmaxsb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 61 = 0x3D
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xA2, 0x17,// Pmaxsd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 62 = 0x3E
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xAB, 0x17,// Pmaxuw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 63 = 0x3F
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xB1, 0x17,// Pmaxud_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 64 = 0x40
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xBA, 0x17,// Pmulld_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 65 = 0x41
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC3, 0x17,// Phminposuw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 66 = 0x42
	0x05,// Dup
		0x3E,// 62
		0x02,// Invalid

	// 128 = 0x80
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x09,// RM
			0x02,// Invalid
			0x4F,// Gv_Ev_32_64
				0xA6, 0x19,// Invept_r32_m128
				0x00,// false
				0x01,// true
		0x02,// Invalid
		0x02,// Invalid

	// 129 = 0x81
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x09,// RM
			0x02,// Invalid
			0x4F,// Gv_Ev_32_64
				0xA8, 0x19,// Invvpid_r32_m128
				0x00,// false
				0x01,// true
		0x02,// Invalid
		0x02,// Invalid

	// 130 = 0x82
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x09,// RM
			0x02,// Invalid
			0x4F,// Gv_Ev_32_64
				0xAA, 0x19,// Invpcid_r32_m128
				0x00,// false
				0x01,// true
		0x02,// Invalid
		0x02,// Invalid

	// 131 = 0x83
	0x05,// Dup
		0x45,// 69
		0x02,// Invalid

	// 200 = 0xC8
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0x9C, 0x1C,// Sha1nexte_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 201 = 0xC9
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0x9F, 0x1C,// Sha1msg1_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 202 = 0xCA
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xA0, 0x1C,// Sha1msg2_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 203 = 0xCB
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xA3, 0x1C,// Sha256rnds2_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 204 = 0xCC
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xA6, 0x1C,// Sha256msg1_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 205 = 0xCD
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xA9, 0x1C,// Sha256msg2_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 206 = 0xCE
	0x02,// Invalid

	// 207 = 0xCF
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xAC, 0x1C,// Gf2p8mulb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 208 = 0xD0
	0x05,// Dup
		0x08,// 8
		0x02,// Invalid

	// 216 = 0xD8
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x02,// Invalid
		0x0E,// Group
			0x08,// ArrayReference
				0x4B,// 0x4B = handlers_Grp_F30F38D8
		0x02,// Invalid

	// 217 = 0xD9
	0x04,// Invalid2

	// 219 = 0xDB
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xB2, 0x1C,// Aesimc_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 220 = 0xDC
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xB4, 0x1C,// Aesenc_xmm_xmmm128
		0xB8,// VW_3
			0xBF, 0x21,// Loadiwkey_xmm_xmm
			0xC0, 0x21,// Aesenc128kl_xmm_m384
		0x02,// Invalid

	// 221 = 0xDD
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xBA, 0x1C,// Aesenclast_xmm_xmmm128
		0x09,// RM
			0x02,// Invalid
			0xB7,// VW_2
				0xC1, 0x21,// Aesdec128kl_xmm_m384
		0x02,// Invalid

	// 222 = 0xDE
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC0, 0x1C,// Aesdec_xmm_xmmm128
		0x09,// RM
			0x02,// Invalid
			0xB7,// VW_2
				0xC2, 0x21,// Aesenc256kl_xmm_m512
		0x02,// Invalid

	// 223 = 0xDF
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC6, 0x1C,// Aesdeclast_xmm_xmmm128
		0x09,// RM
			0x02,// Invalid
			0xB7,// VW_2
				0xC3, 0x21,// Aesdec256kl_xmm_m512
		0x02,// Invalid

	// 224 = 0xE0
	0x05,// Dup
		0x10,// 16
		0x02,// Invalid

	// 240 = 0xF0
	0x12,// MandatoryPrefix4
		0x5E,// Gv_Mv
			0xCC, 0x1C,// Movbe_r16_m16
		0x5E,// Gv_Mv
			0xCC, 0x1C,// Movbe_r16_m16
		0x02,// Invalid
		0x4E,// Gv_Eb_REX
			0xCF, 0x1C,// Crc32_r32_rm8
		0x1C,// 0x1C

	// 241 = 0xF1
	0x12,// MandatoryPrefix4
		0x7A,// Mv_Gv
			0xD1, 0x1C,// Movbe_m16_r16
		0x7A,// Mv_Gv
			0xD1, 0x1C,// Movbe_m16_r16
		0x02,// Invalid
		0x4C,// Gdq_Ev
			0xD4, 0x1C,// Crc32_r32_rm16
		0x1C,// 0x1C

	// 242 = 0xF2
	0x05,// Dup
		0x03,// 3
		0x02,// Invalid

	// 245 = 0xF5
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x09,// RM
			0x02,// Invalid
			0x3C,// Ev_Gv_REX
				0xE1, 0x1C,// Wrussd_m32_r32
		0x02,// Invalid
		0x02,// Invalid

	// 246 = 0xF6
	0x11,// MandatoryPrefix
		0x09,// RM
			0x02,// Invalid
			0x3C,// Ev_Gv_REX
				0xE7, 0x1C,// Wrssd_m32_r32
		0x55,// Gv_Ev_REX
			0xE9, 0x1C,// Adcx_r32_rm32
		0x55,// Gv_Ev_REX
			0xEB, 0x1C,// Adox_r32_rm32
		0x02,// Invalid

	// 247 = 0xF7
	0x02,// Invalid

	// 248 = 0xF8
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x5A,// Gv_M_as
			0xF7, 0x1C,// Movdir64b_r16_m512
		0x5A,// Gv_M_as
			0xFA, 0x1C,// Enqcmds_r16_m512
		0x5A,// Gv_M_as
			0xFD, 0x1C,// Enqcmd_r16_m512

	// 249 = 0xF9
	0x11,// MandatoryPrefix
		0x09,// RM
			0x02,// Invalid
			0x3C,// Ev_Gv_REX
				0x80, 0x1D,// Movdiri_m32_r32
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 250 = 0xFA
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x02,// Invalid
		0x09,// RM
			0xCD,// Gd_Rd
				0xC4, 0x21,// Encodekey128_r32_r32
			0x02,// Invalid
		0x02,// Invalid

	// 251 = 0xFB
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x02,// Invalid
		0x09,// RM
			0xCD,// Gd_Rd
				0xC5, 0x21,// Encodekey256_r32_r32
			0x02,// Invalid
		0x02,// Invalid

	// 252 = 0xFC
	0x11,// MandatoryPrefix
		0x09,// RM
			0x02,// Invalid
			0x3C,// Ev_Gv_REX
				0xE8, 0x25,// Aadd_m32_r32
		0x09,// RM
			0x02,// Invalid
			0x3C,// Ev_Gv_REX
				0xEA, 0x25,// Aand_m32_r32
		0x09,// RM
			0x02,// Invalid
			0x3C,// Ev_Gv_REX
				0xEC, 0x25,// Axor_m32_r32
		0x09,// RM
			0x02,// Invalid
			0x3C,// Ev_Gv_REX
				0xEE, 0x25,// Aor_m32_r32

	// 253 = 0xFD
	0x05,// Dup
		0x03,// 3
		0x02,// Invalid

	// Handlers_0F3A
	0x01,// ArrayReference
	0x80, 0x02,// 0x100
	// 0 = 0x00
	0x05,// Dup
		0x08,// 8
		0x02,// Invalid

	// 8 = 0x08
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0x9B, 0x1D,// Roundps_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 9 = 0x09
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xA1, 0x1D,// Roundpd_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 10 = 0x0A
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xA7, 0x1D,// Roundss_xmm_xmmm32_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 11 = 0x0B
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xAA, 0x1D,// Roundsd_xmm_xmmm64_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 12 = 0x0C
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xAD, 0x1D,// Blendps_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 13 = 0x0D
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xB0, 0x1D,// Blendpd_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 14 = 0x0E
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xB3, 0x1D,// Pblendw_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 15 = 0x0F
	0x11,// MandatoryPrefix
		0x82,// P_Q_Ib
			0xB6, 0x1D,// Palignr_mm_mmm64_imm8
		0xB9,// VWIb_2
			0xB7, 0x1D,// Palignr_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 16 = 0x10
	0x05,// Dup
		0x04,// 4
		0x02,// Invalid

	// 20 = 0x14
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x63,// GvM_VX_Ib
			0xBD, 0x1D,// Pextrb_r32m8_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 21 = 0x15
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x63,// GvM_VX_Ib
			0xC3, 0x1D,// Pextrw_r32m16_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 22 = 0x16
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x63,// GvM_VX_Ib
			0xC9, 0x1D,// Pextrd_rm32_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 23 = 0x17
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x30,// Ed_V_Ib
			0xCF, 0x1D,// Extractps_rm32_xmm_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 24 = 0x18
	0x05,// Dup
		0x08,// 8
		0x02,// Invalid

	// 32 = 0x20
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xBB,// VX_E_Ib
			0xF4, 0x1D,// Pinsrb_xmm_r32m8_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 33 = 0x21
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xFA, 0x1D,// Insertps_xmm_xmmm32_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 34 = 0x22
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xBB,// VX_E_Ib
			0xFD, 0x1D,// Pinsrd_xmm_rm32_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 35 = 0x23
	0x05,// Dup
		0x1D,// 29
		0x02,// Invalid

	// 64 = 0x40
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xB7, 0x1E,// Dpps_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 65 = 0x41
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xBA, 0x1E,// Dppd_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 66 = 0x42
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xBC, 0x1E,// Mpsadbw_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 67 = 0x43
	0x02,// Invalid

	// 68 = 0x44
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xC6, 0x1E,// Pclmulqdq_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 69 = 0x45
	0x05,// Dup
		0x1B,// 27
		0x02,// Invalid

	// 96 = 0x60
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xBA,// VWIb_3
			0x83, 0x1F,// Pcmpestrm_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 97 = 0x61
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xBA,// VWIb_3
			0x87, 0x1F,// Pcmpestri_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 98 = 0x62
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0x8B, 0x1F,// Pcmpistrm_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 99 = 0x63
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0x8D, 0x1F,// Pcmpistri_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 100 = 0x64
	0x05,// Dup
		0x68,// 104
		0x02,// Invalid

	// 204 = 0xCC
	0x11,// MandatoryPrefix
		0xB9,// VWIb_2
			0xD9, 0x1F,// Sha1rnds4_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 205 = 0xCD
	0x02,// Invalid

	// 206 = 0xCE
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xDA, 0x1F,// Gf2p8affineqb_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 207 = 0xCF
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xE0, 0x1F,// Gf2p8affineinvqb_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 208 = 0xD0
	0x05,// Dup
		0x0F,// 15
		0x02,// Invalid

	// 223 = 0xDF
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB9,// VWIb_2
			0xE6, 0x1F,// Aeskeygenassist_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 224 = 0xE0
	0x05,// Dup
		0x10,// 16
		0x02,// Invalid

	// 240 = 0xF0
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x4C,// 0x4C = handlers_Grp_0F3AF0_lo
		0x08,// ArrayReference
			0x4D,// 0x4D = handlers_Grp_0F3AF0_hi

	// 241 = 0xF1
	0x05,// Dup
		0x0F,// 15
		0x02,// Invalid

	// Handlers_0F
	0x01,// ArrayReference
	0x80, 0x02,// 0x100
	// 0 = 0x00
	0x0E,// Group
		0x08,// ArrayReference
			0x1F,// 0x1F = handlers_Grp_0F00

	// 1 = 0x01
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x20,// 0x20 = handlers_Grp_0F01_lo
		0x08,// ArrayReference
			0x21,// 0x21 = handlers_Grp_0F01_hi

	// 2 = 0x02
	0x57,// Gv_Ev3
		0xDE, 0x06,// Lar_r16_rm16

	// 3 = 0x03
	0x57,// Gv_Ev3
		0xE1, 0x06,// Lsl_r16_rm16

	// 4 = 0x04
	0x00,// Bitness
		0x0A,// Options3
			0x02,// Invalid
			0xA4,// Simple
				0xE4, 0x06,// Storeall
			0x80, 0x02,// Loadall286
		0x02,// Invalid

	// 5 = 0x05
	0x00,// Bitness
		0x0A,// Options3
			0xA4,// Simple
				0xE6, 0x06,// Syscall
			0xA4,// Simple
				0xE5, 0x06,// Loadall286
			0x80, 0x02,// Loadall286
		0xA4,// Simple
			0xE6, 0x06,// Syscall

	// 6 = 0x06
	0xA4,// Simple
		0xE7, 0x06,// Clts

	// 7 = 0x07
	0x00,// Bitness
		0x0A,// Options3
			0xA7,// Simple2_3b
				0xE9, 0x06,// Sysretd
				0xE9, 0x06,// Sysretd
				0xEA, 0x06,// Sysretq
			0xA4,// Simple
				0xE8, 0x06,// Loadall386
			0x80, 0x04,// Loadall386
		0xA7,// Simple2_3b
			0xE9, 0x06,// Sysretd
			0xE9, 0x06,// Sysretd
			0xEA, 0x06,// Sysretq

	// 8 = 0x08
	0xA4,// Simple
		0xEB, 0x06,// Invd

	// 9 = 0x09
	0xBD,// Wbinvd

	// 10 = 0x0A
	0x00,// Bitness
		0x0A,// Options3
			0x02,// Invalid
			0xA4,// Simple
				0xEE, 0x06,// Cl1invmb
			0x80, 0x08,// Cl1invmb
		0x02,// Invalid

	// 11 = 0x0B
	0xA4,// Simple
		0xEF, 0x06,// Ud2

	// 12 = 0x0C
	0x02,// Invalid

	// 13 = 0x0D
	0x9E,// Reservednop
		0x07,// HandlerReference
			0x35,// 0x35 = reservedNop_0F0D
		0x07,// HandlerReference
			0x3F,// 0x3F = grp0F0D

	// 14 = 0x0E
	0x0A,// Options3
		0xA4,// Simple
			0xF6, 0x06,// Femms
		0xA4,// Simple
			0xD1, 0x23,// Rdudbg
		0x80, 0x80, 0x02,// Udbg

	// 15 = 0x0F
	0x0A,// Options3
		0x16,// D3NOW
		0xA4,// Simple
			0xD2, 0x23,// Wrudbg
		0x80, 0x80, 0x02,// Udbg

	// 16 = 0x10
	0x00,// Bitness
		0x0A,// Options3
			0x11,// MandatoryPrefix
				0xB7,// VW_2
					0xFD, 0x06,// Movups_xmm_xmmm128
				0xB7,// VW_2
					0x83, 0x07,// Movupd_xmm_xmmm128
				0xB7,// VW_2
					0x89, 0x07,// Movss_xmm_xmmm32
				0xB7,// VW_2
					0x8E, 0x07,// Movsd_xmm_xmmm64
			0x2B,// Eb_Gb_1
				0xF7, 0x06,// Umov_rm8_r8
			0x08,// Umov
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xFD, 0x06,// Movups_xmm_xmmm128
			0xB7,// VW_2
				0x83, 0x07,// Movupd_xmm_xmmm128
			0xB7,// VW_2
				0x89, 0x07,// Movss_xmm_xmmm32
			0xB7,// VW_2
				0x8E, 0x07,// Movsd_xmm_xmmm64

	// 17 = 0x11
	0x00,// Bitness
		0x0A,// Options3
			0x11,// MandatoryPrefix
				0xBE,// WV
					0x93, 0x07,// Movups_xmmm128_xmm
				0xBE,// WV
					0x99, 0x07,// Movupd_xmmm128_xmm
				0xBE,// WV
					0x9F, 0x07,// Movss_xmmm32_xmm
				0xBE,// WV
					0xA4, 0x07,// Movsd_xmmm64_xmm
			0x38,// Ev_Gv_3b
				0xF8, 0x06,// Umov_rm16_r16
			0x08,// Umov
		0x11,// MandatoryPrefix
			0xBE,// WV
				0x93, 0x07,// Movups_xmmm128_xmm
			0xBE,// WV
				0x99, 0x07,// Movupd_xmmm128_xmm
			0xBE,// WV
				0x9F, 0x07,// Movss_xmmm32_xmm
			0xBE,// WV
				0xA4, 0x07,// Movsd_xmmm64_xmm

	// 18 = 0x12
	0x00,// Bitness
		0x0A,// Options3
			0x11,// MandatoryPrefix
				0xB8,// VW_3
					0xA9, 0x07,// Movhlps_xmm_xmm
					0xAA, 0x07,// Movlps_xmm_m64
				0xB3,// VM
					0xAF, 0x07,// Movlpd_xmm_m64
				0xB7,// VW_2
					0xB2, 0x07,// Movsldup_xmm_xmmm128
				0xB7,// VW_2
					0xB8, 0x07,// Movddup_xmm_xmmm64
			0x4B,// Gb_Eb
				0xFA, 0x06,// Umov_r8_rm8
			0x08,// Umov
		0x11,// MandatoryPrefix
			0xB8,// VW_3
				0xA9, 0x07,// Movhlps_xmm_xmm
				0xAA, 0x07,// Movlps_xmm_m64
			0xB3,// VM
				0xAF, 0x07,// Movlpd_xmm_m64
			0xB7,// VW_2
				0xB2, 0x07,// Movsldup_xmm_xmmm128
			0xB7,// VW_2
				0xB8, 0x07,// Movddup_xmm_xmmm64

	// 19 = 0x13
	0x00,// Bitness
		0x0A,// Options3
			0x11,// MandatoryPrefix
				0x79,// MV
					0xBE, 0x07,// Movlps_m64_xmm
				0x79,// MV
					0xC1, 0x07,// Movlpd_m64_xmm
				0x02,// Invalid
				0x02,// Invalid
			0x51,// Gv_Ev_3b
				0xFB, 0x06,// Umov_r16_rm16
			0x08,// Umov
		0x11,// MandatoryPrefix
			0x79,// MV
				0xBE, 0x07,// Movlps_m64_xmm
			0x79,// MV
				0xC1, 0x07,// Movlpd_m64_xmm
			0x02,// Invalid
			0x02,// Invalid

	// 20 = 0x14
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xC4, 0x07,// Unpcklps_xmm_xmmm128
		0xB7,// VW_2
			0xCA, 0x07,// Unpcklpd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 21 = 0x15
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xD0, 0x07,// Unpckhps_xmm_xmmm128
		0xB7,// VW_2
			0xD6, 0x07,// Unpckhpd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 22 = 0x16
	0x11,// MandatoryPrefix
		0xB8,// VW_3
			0xDC, 0x07,// Movlhps_xmm_xmm
			0xDF, 0x07,// Movhps_xmm_m64
		0xB3,// VM
			0xE2, 0x07,// Movhpd_xmm_m64
		0xB7,// VW_2
			0xE5, 0x07,// Movshdup_xmm_xmmm128
		0x02,// Invalid

	// 23 = 0x17
	0x11,// MandatoryPrefix
		0x79,// MV
			0xEB, 0x07,// Movhps_m64_xmm
		0x79,// MV
			0xEE, 0x07,// Movhpd_m64_xmm
		0x02,// Invalid
		0x02,// Invalid

	// 24 = 0x18
	0x07,// HandlerReference
		0x41,// 0x41 = grp0F18

	// 25 = 0x19
	0x07,// HandlerReference
		0x37,// 0x37 = reservedNop_0F19

	// 26 = 0x1A
	0x9E,// Reservednop
		0x07,// HandlerReference
			0x38,// 0x38 = reservedNop_0F1A
		0x0C,// Options_DontReadModRM
			0x07,// HandlerReference
				0x38,// 0x38 = reservedNop_0F1A
			0x11,// MandatoryPrefix
				0x09,// RM
					0x07,// HandlerReference
						0x38,// 0x38 = reservedNop_0F1A
					0x1F,// B_MIB
						0x8D, 0x08,// Bndldx_bnd_mib
				0x1D,// B_BM
					0x8E, 0x08,// Bndmov_bnd_bndm64
				0x1E,// B_Ev
					0x90, 0x08,// Bndcl_bnd_rm32
					0x01,// true
				0x1E,// B_Ev
					0x92, 0x08,// Bndcu_bnd_rm32
					0x01,// true
			0x80, 0x80, 0x20,// MPX

	// 27 = 0x1B
	0x9E,// Reservednop
		0x07,// HandlerReference
			0x39,// 0x39 = reservedNop_0F1B
		0x0C,// Options_DontReadModRM
			0x07,// HandlerReference
				0x39,// 0x39 = reservedNop_0F1B
			0x11,// MandatoryPrefix
				0x09,// RM
					0x07,// HandlerReference
						0x39,// 0x39 = reservedNop_0F1B
					0x76,// MIB_B
						0x94, 0x08,// Bndstx_mib_bnd
				0x20,// BM_B
					0x95, 0x08,// Bndmov_bndm64_bnd
				0x09,// RM
					0x07,// HandlerReference
						0x39,// 0x39 = reservedNop_0F1B
					0x1E,// B_Ev
						0x97, 0x08,// Bndmk_bnd_m32
						0x00,// false
				0x1E,// B_Ev
					0x99, 0x08,// Bndcn_bnd_rm32
					0x01,// true
			0x80, 0x80, 0x20,// MPX

	// 28 = 0x1C
	0x07,// HandlerReference
		0x43,// 0x43 = grp0F1C

	// 29 = 0x1D
	0x07,// HandlerReference
		0x3B,// 0x3B = reservedNop_0F1D

	// 30 = 0x1E
	0x07,// HandlerReference
		0x47,// 0x47 = grp0F1E

	// 31 = 0x1F
	0x07,// HandlerReference
		0x49,// 0x49 = grp0F1F

	// 32 = 0x20
	0x8D,// R_C_3a
		0xA3, 0x08,// Mov_r32_cr
		0xB9,// CR0

	// 33 = 0x21
	0x8D,// R_C_3a
		0xA5, 0x08,// Mov_r32_dr
		0xC9,// DR0

	// 34 = 0x22
	0x23,// C_R_3a
		0xA7, 0x08,// Mov_cr_r32
		0xB9,// CR0

	// 35 = 0x23
	0x23,// C_R_3a
		0xA9, 0x08,// Mov_dr_r32
		0xC9,// DR0

	// 36 = 0x24
	0x00,// Bitness
		0x0A,// Options3
			0x02,// Invalid
			0x8E,// R_C_3b
				0xAB, 0x08,// Mov_r32_tr
				0xE9,// TR0
			0x80, 0x10,// MovTr
		0x02,// Invalid

	// 37 = 0x25
	0x02,// Invalid

	// 38 = 0x26
	0x00,// Bitness
		0x0A,// Options3
			0x02,// Invalid
			0x24,// C_R_3b
				0xAC, 0x08,// Mov_tr_r32
				0xE9,// TR0
			0x80, 0x10,// MovTr
		0x02,// Invalid

	// 39 = 0x27
	0x02,// Invalid

	// 40 = 0x28
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xAD, 0x08,// Movaps_xmm_xmmm128
		0xB7,// VW_2
			0xB3, 0x08,// Movapd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 41 = 0x29
	0x11,// MandatoryPrefix
		0xBE,// WV
			0xB9, 0x08,// Movaps_xmmm128_xmm
		0xBE,// WV
			0xBF, 0x08,// Movapd_xmmm128_xmm
		0x02,// Invalid
		0x02,// Invalid

	// 42 = 0x2A
	0x11,// MandatoryPrefix
		0xB5,// VQ
			0xC5, 0x08,// Cvtpi2ps_xmm_mmm64
		0xB5,// VQ
			0xC6, 0x08,// Cvtpi2pd_xmm_mmm64
		0xB2,// V_Ev
			0xC7, 0x08,// Cvtsi2ss_xmm_rm32
		0xB2,// V_Ev
			0xCD, 0x08,// Cvtsi2sd_xmm_rm32

	// 43 = 0x2B
	0x11,// MandatoryPrefix
		0x79,// MV
			0xD3, 0x08,// Movntps_m128_xmm
		0x79,// MV
			0xD9, 0x08,// Movntpd_m128_xmm
		0x79,// MV
			0xDF, 0x08,// Movntss_m32_xmm
		0x79,// MV
			0xE0, 0x08,// Movntsd_m64_xmm

	// 44 = 0x2C
	0x11,// MandatoryPrefix
		0x84,// P_W
			0xE1, 0x08,// Cvttps2pi_mm_xmmm64
		0x84,// P_W
			0xE2, 0x08,// Cvttpd2pi_mm_xmmm128
		0x62,// Gv_W
			0xE3, 0x08,// Cvttss2si_r32_xmmm32
		0x62,// Gv_W
			0xE9, 0x08,// Cvttsd2si_r32_xmmm64

	// 45 = 0x2D
	0x11,// MandatoryPrefix
		0x84,// P_W
			0xEF, 0x08,// Cvtps2pi_mm_xmmm64
		0x84,// P_W
			0xF0, 0x08,// Cvtpd2pi_mm_xmmm128
		0x62,// Gv_W
			0xF1, 0x08,// Cvtss2si_r32_xmmm32
		0x62,// Gv_W
			0xF7, 0x08,// Cvtsd2si_r32_xmmm64

	// 46 = 0x2E
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xFD, 0x08,// Ucomiss_xmm_xmmm32
		0xB7,// VW_2
			0x80, 0x09,// Ucomisd_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 47 = 0x2F
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0x83, 0x09,// Comiss_xmm_xmmm32
		0xB7,// VW_2
			0x84, 0x09,// Comisd_xmm_xmmm64
		0x02,// Invalid
		0x02,// Invalid

	// 48 = 0x30
	0xA4,// Simple
		0x89, 0x09,// Wrmsr

	// 49 = 0x31
	0xA4,// Simple
		0x8A, 0x09,// Rdtsc

	// 50 = 0x32
	0xA4,// Simple
		0x8B, 0x09,// Rdmsr

	// 51 = 0x33
	0xA4,// Simple
		0x8C, 0x09,// Rdpmc

	// 52 = 0x34
	0xA4,// Simple
		0x8D, 0x09,// Sysenter

	// 53 = 0x35
	0xAA,// Simple4
		0x8E, 0x09,// Sysexitd

	// 54 = 0x36
	0xC8,// Options1632_1
		0x02,// Invalid
		0x0E,// Group
			0x08,// ArrayReference
				0x22,// 0x22 = handlers_Grp_0F36_Cyrix
		0x80, 0x80, 0x40,// Cyrix

	// 55 = 0x37
	0xC8,// Options1632_1
		0x14,// MandatoryPrefix_NoModRM
			0xC7,// Simple4b
				0x90, 0x09,// Getsecd
				0xFF, 0x20,// Getsecq
			0x03,// Invalid_NoModRM
			0x03,// Invalid_NoModRM
			0x03,// Invalid_NoModRM
		0x0E,// Group
			0x08,// ArrayReference
				0x23,// 0x23 = handlers_Grp_0F37_Cyrix
		0x80, 0x80, 0x40,// Cyrix

	// 56 = 0x38
	0xC8,// Options1632_1
		0x0D,// AnotherTable
			0x08,// ArrayReference
				0x4E,// 0x4E = Handlers_0F38
		0xA4,// Simple
			0x90, 0x21,// Smint
		0x80, 0x80, 0x40,// Cyrix

	// 57 = 0x39
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0x91, 0x21,// Dmint
		0x80, 0x80, 0x80, 0x02,// Cyrix_DMI

	// 58 = 0x3A
	0xC9,// Options1632_2
		0x0D,// AnotherTable
			0x08,// ArrayReference
				0x4F,// 0x4F = Handlers_0F3A
		0xA4,// Simple
			0x92, 0x21,// Rdm
		0x80, 0x80, 0x80, 0x02,// Cyrix_DMI
		0xA4,// Simple
			0x9A, 0x21,// Bb0_reset
		0x80, 0x80, 0x40,// Cyrix

	// 59 = 0x3B
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0x9B, 0x21,// Bb1_reset
		0x80, 0x80, 0x40,// Cyrix

	// 60 = 0x3C
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0x9C, 0x21,// Cpu_write
		0x80, 0x80, 0x40,// Cyrix

	// 61 = 0x3D
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0x9D, 0x21,// Cpu_read
		0x80, 0x80, 0x40,// Cyrix

	// 62 = 0x3E
	0x02,// Invalid

	// 63 = 0x3F
	0xC8,// Options1632_1
		0x02,// Invalid
		0xA4,// Simple
			0x9E, 0x21,// Altinst
		0x80, 0x80, 0x80, 0x04,// ALTINST

	// 64 = 0x40
	0x50,// Gv_Ev_3a
		0x91, 0x09,// Cmovo_r16_rm16

	// 65 = 0x41
	0x50,// Gv_Ev_3a
		0x94, 0x09,// Cmovno_r16_rm16

	// 66 = 0x42
	0x50,// Gv_Ev_3a
		0x97, 0x09,// Cmovb_r16_rm16

	// 67 = 0x43
	0x50,// Gv_Ev_3a
		0x9A, 0x09,// Cmovae_r16_rm16

	// 68 = 0x44
	0x50,// Gv_Ev_3a
		0x9D, 0x09,// Cmove_r16_rm16

	// 69 = 0x45
	0x50,// Gv_Ev_3a
		0xA0, 0x09,// Cmovne_r16_rm16

	// 70 = 0x46
	0x50,// Gv_Ev_3a
		0xA3, 0x09,// Cmovbe_r16_rm16

	// 71 = 0x47
	0x50,// Gv_Ev_3a
		0xA6, 0x09,// Cmova_r16_rm16

	// 72 = 0x48
	0x50,// Gv_Ev_3a
		0xA9, 0x09,// Cmovs_r16_rm16

	// 73 = 0x49
	0x50,// Gv_Ev_3a
		0xAC, 0x09,// Cmovns_r16_rm16

	// 74 = 0x4A
	0x50,// Gv_Ev_3a
		0xAF, 0x09,// Cmovp_r16_rm16

	// 75 = 0x4B
	0x50,// Gv_Ev_3a
		0xB2, 0x09,// Cmovnp_r16_rm16

	// 76 = 0x4C
	0x50,// Gv_Ev_3a
		0xB5, 0x09,// Cmovl_r16_rm16

	// 77 = 0x4D
	0x50,// Gv_Ev_3a
		0xB8, 0x09,// Cmovge_r16_rm16

	// 78 = 0x4E
	0x50,// Gv_Ev_3a
		0xBB, 0x09,// Cmovle_r16_rm16

	// 79 = 0x4F
	0x50,// Gv_Ev_3a
		0xBE, 0x09,// Cmovg_r16_rm16

	// 80 = 0x50
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0x61,// Gv_RX
				0xE0, 0x09,// Movmskps_r32_xmm
			0x61,// Gv_RX
				0xE6, 0x09,// Movmskpd_r32_xmm
			0x02,// Invalid
			0x02,// Invalid
		0x81,// P_Q
			0x9F, 0x21,// Paveb_mm_mmm64
		0x80, 0x80, 0x40,// Cyrix

	// 81 = 0x51
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xEC, 0x09,// Sqrtps_xmm_xmmm128
			0xB7,// VW_2
				0xF2, 0x09,// Sqrtpd_xmm_xmmm128
			0xB7,// VW_2
				0xF8, 0x09,// Sqrtss_xmm_xmmm32
			0xB7,// VW_2
				0xFB, 0x09,// Sqrtsd_xmm_xmmm64
		0x81,// P_Q
			0xA0, 0x21,// Paddsiw_mm_mmm64
		0x80, 0x80, 0x40,// Cyrix

	// 82 = 0x52
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xFE, 0x09,// Rsqrtps_xmm_xmmm128
			0x02,// Invalid
			0xB7,// VW_2
				0x81, 0x0A,// Rsqrtss_xmm_xmmm32
			0x02,// Invalid
		0x81,// P_Q
			0xA1, 0x21,// Pmagw_mm_mmm64
		0x80, 0x80, 0x40,// Cyrix

	// 83 = 0x53
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0x83, 0x0A,// Rcpps_xmm_xmmm128
		0x02,// Invalid
		0xB7,// VW_2
			0x86, 0x0A,// Rcpss_xmm_xmmm32
		0x02,// Invalid

	// 84 = 0x54
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0x88, 0x0A,// Andps_xmm_xmmm128
			0xB7,// VW_2
				0x8E, 0x0A,// Andpd_xmm_xmmm128
			0x02,// Invalid
			0x02,// Invalid
		0x09,// RM
			0x02,// Invalid
			0x81,// P_Q
				0xA2, 0x21,// Pdistib_mm_m64
		0x80, 0x80, 0x40,// Cyrix

	// 85 = 0x55
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0x94, 0x0A,// Andnps_xmm_xmmm128
			0xB7,// VW_2
				0x9A, 0x0A,// Andnpd_xmm_xmmm128
			0x02,// Invalid
			0x02,// Invalid
		0x81,// P_Q
			0xA3, 0x21,// Psubsiw_mm_mmm64
		0x80, 0x80, 0x40,// Cyrix

	// 86 = 0x56
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xA0, 0x0A,// Orps_xmm_xmmm128
		0xB7,// VW_2
			0xA6, 0x0A,// Orpd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 87 = 0x57
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xAC, 0x0A,// Xorps_xmm_xmmm128
		0xB7,// VW_2
			0xB2, 0x0A,// Xorpd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 88 = 0x58
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xB8, 0x0A,// Addps_xmm_xmmm128
			0xB7,// VW_2
				0xBE, 0x0A,// Addpd_xmm_xmmm128
			0xB7,// VW_2
				0xC4, 0x0A,// Addss_xmm_xmmm32
			0xB7,// VW_2
				0xC7, 0x0A,// Addsd_xmm_xmmm64
		0x09,// RM
			0x02,// Invalid
			0x81,// P_Q
				0xA4, 0x21,// Pmvzb_mm_m64
		0x80, 0x80, 0x40,// Cyrix

	// 89 = 0x59
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xCA, 0x0A,// Mulps_xmm_xmmm128
			0xB7,// VW_2
				0xD0, 0x0A,// Mulpd_xmm_xmmm128
			0xB7,// VW_2
				0xD6, 0x0A,// Mulss_xmm_xmmm32
			0xB7,// VW_2
				0xD9, 0x0A,// Mulsd_xmm_xmmm64
		0x81,// P_Q
			0xA5, 0x21,// Pmulhrw_mm_mmm64
		0x80, 0x80, 0x40,// Cyrix

	// 90 = 0x5A
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xDC, 0x0A,// Cvtps2pd_xmm_xmmm64
			0xB7,// VW_2
				0xE2, 0x0A,// Cvtpd2ps_xmm_xmmm128
			0xB7,// VW_2
				0xE8, 0x0A,// Cvtss2sd_xmm_xmmm32
			0xB7,// VW_2
				0xEB, 0x0A,// Cvtsd2ss_xmm_xmmm64
		0x09,// RM
			0x02,// Invalid
			0x81,// P_Q
				0xA6, 0x21,// Pmvnzb_mm_m64
		0x80, 0x80, 0x40,// Cyrix

	// 91 = 0x5B
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xEE, 0x0A,// Cvtdq2ps_xmm_xmmm128
			0xB7,// VW_2
				0xF7, 0x0A,// Cvtps2dq_xmm_xmmm128
			0xB7,// VW_2
				0xFD, 0x0A,// Cvttps2dq_xmm_xmmm128
			0x02,// Invalid
		0x09,// RM
			0x02,// Invalid
			0x81,// P_Q
				0xA7, 0x21,// Pmvlzb_mm_m64
		0x80, 0x80, 0x40,// Cyrix

	// 92 = 0x5C
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0x83, 0x0B,// Subps_xmm_xmmm128
			0xB7,// VW_2
				0x89, 0x0B,// Subpd_xmm_xmmm128
			0xB7,// VW_2
				0x8F, 0x0B,// Subss_xmm_xmmm32
			0xB7,// VW_2
				0x92, 0x0B,// Subsd_xmm_xmmm64
		0x09,// RM
			0x02,// Invalid
			0x81,// P_Q
				0xA8, 0x21,// Pmvgezb_mm_m64
		0x80, 0x80, 0x40,// Cyrix

	// 93 = 0x5D
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0x95, 0x0B,// Minps_xmm_xmmm128
			0xB7,// VW_2
				0x9B, 0x0B,// Minpd_xmm_xmmm128
			0xB7,// VW_2
				0xA1, 0x0B,// Minss_xmm_xmmm32
			0xB7,// VW_2
				0xA4, 0x0B,// Minsd_xmm_xmmm64
		0x81,// P_Q
			0xA9, 0x21,// Pmulhriw_mm_mmm64
		0x80, 0x80, 0x40,// Cyrix

	// 94 = 0x5E
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0xB7,// VW_2
				0xA7, 0x0B,// Divps_xmm_xmmm128
			0xB7,// VW_2
				0xAD, 0x0B,// Divpd_xmm_xmmm128
			0xB7,// VW_2
				0xB3, 0x0B,// Divss_xmm_xmmm32
			0xB7,// VW_2
				0xB6, 0x0B,// Divsd_xmm_xmmm64
		0x09,// RM
			0x02,// Invalid
			0x81,// P_Q
				0xAA, 0x21,// Pmachriw_mm_m64
		0x80, 0x80, 0x40,// Cyrix

	// 95 = 0x5F
	0x11,// MandatoryPrefix
		0xB7,// VW_2
			0xB9, 0x0B,// Maxps_xmm_xmmm128
		0xB7,// VW_2
			0xBF, 0x0B,// Maxpd_xmm_xmmm128
		0xB7,// VW_2
			0xC5, 0x0B,// Maxss_xmm_xmmm32
		0xB7,// VW_2
			0xC8, 0x0B,// Maxsd_xmm_xmmm64

	// 96 = 0x60
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xCB, 0x0B,// Punpcklbw_mm_mmm32
		0xB7,// VW_2
			0xCC, 0x0B,// Punpcklbw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 97 = 0x61
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xD2, 0x0B,// Punpcklwd_mm_mmm32
		0xB7,// VW_2
			0xD3, 0x0B,// Punpcklwd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 98 = 0x62
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xD9, 0x0B,// Punpckldq_mm_mmm32
		0xB7,// VW_2
			0xDA, 0x0B,// Punpckldq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 99 = 0x63
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xE0, 0x0B,// Packsswb_mm_mmm64
		0xB7,// VW_2
			0xE1, 0x0B,// Packsswb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 100 = 0x64
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xE7, 0x0B,// Pcmpgtb_mm_mmm64
		0xB7,// VW_2
			0xE8, 0x0B,// Pcmpgtb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 101 = 0x65
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xEE, 0x0B,// Pcmpgtw_mm_mmm64
		0xB7,// VW_2
			0xEF, 0x0B,// Pcmpgtw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 102 = 0x66
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xF5, 0x0B,// Pcmpgtd_mm_mmm64
		0xB7,// VW_2
			0xF6, 0x0B,// Pcmpgtd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 103 = 0x67
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xFC, 0x0B,// Packuswb_mm_mmm64
		0xB7,// VW_2
			0xFD, 0x0B,// Packuswb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 104 = 0x68
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x83, 0x0C,// Punpckhbw_mm_mmm64
		0xB7,// VW_2
			0x84, 0x0C,// Punpckhbw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 105 = 0x69
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x8A, 0x0C,// Punpckhwd_mm_mmm64
		0xB7,// VW_2
			0x8B, 0x0C,// Punpckhwd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 106 = 0x6A
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x91, 0x0C,// Punpckhdq_mm_mmm64
		0xB7,// VW_2
			0x92, 0x0C,// Punpckhdq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 107 = 0x6B
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x98, 0x0C,// Packssdw_mm_mmm64
		0xB7,// VW_2
			0x99, 0x0C,// Packssdw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 108 = 0x6C
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0x9F, 0x0C,// Punpcklqdq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 109 = 0x6D
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xA5, 0x0C,// Punpckhqdq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 110 = 0x6E
	0x11,// MandatoryPrefix
		0x7F,// P_Ev
			0xAB, 0x0C,// Movd_mm_rm32
		0xBC,// VX_Ev
			0xAD, 0x0C,// Movd_xmm_rm32
		0x02,// Invalid
		0x02,// Invalid

	// 111 = 0x6F
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB3, 0x0C,// Movq_mm_mmm64
		0xB7,// VW_2
			0xB4, 0x0C,// Movdqa_xmm_xmmm128
		0xB7,// VW_2
			0xBD, 0x0C,// Movdqu_xmm_xmmm128
		0x02,// Invalid

	// 112 = 0x70
	0x11,// MandatoryPrefix
		0x82,// P_Q_Ib
			0xCC, 0x0C,// Pshufw_mm_mmm64_imm8
		0xB9,// VWIb_2
			0xCD, 0x0C,// Pshufd_xmm_xmmm128_imm8
		0xB9,// VWIb_2
			0xD3, 0x0C,// Pshufhw_xmm_xmmm128_imm8
		0xB9,// VWIb_2
			0xD9, 0x0C,// Pshuflw_xmm_xmmm128_imm8

	// 113 = 0x71
	0x0E,// Group
		0x08,// ArrayReference
			0x30,// 0x30 = handlers_Grp_0F71

	// 114 = 0x72
	0x0E,// Group
		0x08,// ArrayReference
			0x31,// 0x31 = handlers_Grp_0F72

	// 115 = 0x73
	0x0E,// Group
		0x08,// ArrayReference
			0x32,// 0x32 = handlers_Grp_0F73

	// 116 = 0x74
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB2, 0x0D,// Pcmpeqb_mm_mmm64
		0xB7,// VW_2
			0xB3, 0x0D,// Pcmpeqb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 117 = 0x75
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB9, 0x0D,// Pcmpeqw_mm_mmm64
		0xB7,// VW_2
			0xBA, 0x0D,// Pcmpeqw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 118 = 0x76
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xC0, 0x0D,// Pcmpeqd_mm_mmm64
		0xB7,// VW_2
			0xC1, 0x0D,// Pcmpeqd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 119 = 0x77
	0x14,// MandatoryPrefix_NoModRM
		0xA4,// Simple
			0xC7, 0x0D,// Emms
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM
		0x03,// Invalid_NoModRM

	// 120 = 0x78
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0x36,// Ev_Gv_32_64
				0xCA, 0x0D,// Vmread_rm32_r32
			0x0E,// Group
				0x08,// ArrayReference
					0x4A,// 0x4A = handlers_Grp_660F78
			0x02,// Invalid
			0xB6,// VRIbIb
				0xDB, 0x0D,// Insertq_xmm_xmm_imm8_imm8
		0xCA,// M_Sw
			0x93, 0x21,// Svdc_m80_Sreg
		0x80, 0x80, 0x40,// Cyrix

	// 121 = 0x79
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0x4F,// Gv_Ev_32_64
				0xDE, 0x0D,// Vmwrite_r32_rm32
				0x01,// true
				0x01,// true
			0x09,// RM
				0xB8,// VW_3
					0xE6, 0x0D,// Extrq_xmm_xmm
					0x00,// INVALID
				0x02,// Invalid
			0x02,// Invalid
			0x09,// RM
				0xB8,// VW_3
					0xEF, 0x0D,// Insertq_xmm_xmm
					0x00,// INVALID
				0x02,// Invalid
		0xCB,// Sw_M
			0x94, 0x21,// Rsdc_Sreg_m80
		0x80, 0x80, 0x40,// Cyrix

	// 122 = 0x7A
	0xC8,// Options1632_1
		0x02,// Invalid
		0x0E,// Group
			0x08,// ArrayReference
				0x24,// 0x24 = handlers_Grp_0F7A_Cyrix
		0x80, 0x80, 0x40,// Cyrix

	// 123 = 0x7B
	0xC8,// Options1632_1
		0x02,// Invalid
		0x0E,// Group
			0x08,// ArrayReference
				0x25,// 0x25 = handlers_Grp_0F7B_Cyrix
		0x80, 0x80, 0x40,// Cyrix

	// 124 = 0x7C
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0x02,// Invalid
			0xB7,// VW_2
				0x8E, 0x0E,// Haddpd_xmm_xmmm128
			0x02,// Invalid
			0xB7,// VW_2
				0x91, 0x0E,// Haddps_xmm_xmmm128
		0x0E,// Group
			0x08,// ArrayReference
				0x26,// 0x26 = handlers_Grp_0F7C_Cyrix
		0x80, 0x80, 0x40,// Cyrix

	// 125 = 0x7D
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0x02,// Invalid
			0xB7,// VW_2
				0x94, 0x0E,// Hsubpd_xmm_xmmm128
			0x02,// Invalid
			0xB7,// VW_2
				0x97, 0x0E,// Hsubps_xmm_xmmm128
		0x0E,// Group
			0x08,// ArrayReference
				0x27,// 0x27 = handlers_Grp_0F7D_Cyrix
		0x80, 0x80, 0x40,// Cyrix

	// 126 = 0x7E
	0xC8,// Options1632_1
		0x11,// MandatoryPrefix
			0x43,// Ev_P
				0x9A, 0x0E,// Movd_rm32_mm
			0x46,// Ev_VX
				0x9C, 0x0E,// Movd_rm32_xmm
			0xB7,// VW_2
				0xA2, 0x0E,// Movq_xmm_xmmm64
			0x02,// Invalid
		0xA4,// Simple
			0x99, 0x21,// Smint_0F7E
		0x80, 0x80, 0x80, 0x01,// Cyrix_SMINT_0F7E

	// 127 = 0x7F
	0x11,// MandatoryPrefix
		0x8C,// Q_P
			0xA5, 0x0E,// Movq_mmm64_mm
		0xBE,// WV
			0xA6, 0x0E,// Movdqa_xmmm128_xmm
		0xBE,// WV
			0xAF, 0x0E,// Movdqu_xmmm128_xmm
		0x02,// Invalid

	// 128 = 0x80
	0x6D,// Jz
		0xBE, 0x0E,// Jo_rel16

	// 129 = 0x81
	0x6D,// Jz
		0xC1, 0x0E,// Jno_rel16

	// 130 = 0x82
	0x6D,// Jz
		0xC4, 0x0E,// Jb_rel16

	// 131 = 0x83
	0x6D,// Jz
		0xC7, 0x0E,// Jae_rel16

	// 132 = 0x84
	0x6D,// Jz
		0xCA, 0x0E,// Je_rel16

	// 133 = 0x85
	0x6D,// Jz
		0xCD, 0x0E,// Jne_rel16

	// 134 = 0x86
	0x6D,// Jz
		0xD0, 0x0E,// Jbe_rel16

	// 135 = 0x87
	0x6D,// Jz
		0xD3, 0x0E,// Ja_rel16

	// 136 = 0x88
	0x6D,// Jz
		0xD6, 0x0E,// Js_rel16

	// 137 = 0x89
	0x6D,// Jz
		0xD9, 0x0E,// Jns_rel16

	// 138 = 0x8A
	0x6D,// Jz
		0xDC, 0x0E,// Jp_rel16

	// 139 = 0x8B
	0x6D,// Jz
		0xDF, 0x0E,// Jnp_rel16

	// 140 = 0x8C
	0x6D,// Jz
		0xE2, 0x0E,// Jl_rel16

	// 141 = 0x8D
	0x6D,// Jz
		0xE5, 0x0E,// Jge_rel16

	// 142 = 0x8E
	0x6D,// Jz
		0xE8, 0x0E,// Jle_rel16

	// 143 = 0x8F
	0x6D,// Jz
		0xEB, 0x0E,// Jg_rel16

	// 144 = 0x90
	0x28,// Eb_1
		0xEE, 0x0E,// Seto_rm8

	// 145 = 0x91
	0x28,// Eb_1
		0xEF, 0x0E,// Setno_rm8

	// 146 = 0x92
	0x28,// Eb_1
		0xF0, 0x0E,// Setb_rm8

	// 147 = 0x93
	0x28,// Eb_1
		0xF1, 0x0E,// Setae_rm8

	// 148 = 0x94
	0x28,// Eb_1
		0xF2, 0x0E,// Sete_rm8

	// 149 = 0x95
	0x28,// Eb_1
		0xF3, 0x0E,// Setne_rm8

	// 150 = 0x96
	0x28,// Eb_1
		0xF4, 0x0E,// Setbe_rm8

	// 151 = 0x97
	0x28,// Eb_1
		0xF5, 0x0E,// Seta_rm8

	// 152 = 0x98
	0x28,// Eb_1
		0xF6, 0x0E,// Sets_rm8

	// 153 = 0x99
	0x28,// Eb_1
		0xF7, 0x0E,// Setns_rm8

	// 154 = 0x9A
	0x28,// Eb_1
		0xF8, 0x0E,// Setp_rm8

	// 155 = 0x9B
	0x28,// Eb_1
		0xF9, 0x0E,// Setnp_rm8

	// 156 = 0x9C
	0x28,// Eb_1
		0xFA, 0x0E,// Setl_rm8

	// 157 = 0x9D
	0x28,// Eb_1
		0xFB, 0x0E,// Setge_rm8

	// 158 = 0x9E
	0x28,// Eb_1
		0xFC, 0x0E,// Setle_rm8

	// 159 = 0x9F
	0x28,// Eb_1
		0xFD, 0x0E,// Setg_rm8

	// 160 = 0xA0
	0x88,// PushOpSizeReg_4a
		0x96, 0x0F,// Pushw_FS
		0x4B,// FS

	// 161 = 0xA1
	0x88,// PushOpSizeReg_4a
		0x99, 0x0F,// Popw_FS
		0x4B,// FS

	// 162 = 0xA2
	0xA4,// Simple
		0x9C, 0x0F,// Cpuid

	// 163 = 0xA3
	0x37,// Ev_Gv_3a
		0x9D, 0x0F,// Bt_rm16_r16

	// 164 = 0xA4
	0x3B,// Ev_Gv_Ib
		0xA0, 0x0F,// Shld_rm16_r16_imm8

	// 165 = 0xA5
	0x3A,// Ev_Gv_CL
		0xA3, 0x0F,// Shld_rm16_r16_CL

	// 166 = 0xA6
	0x00,// Bitness
		0x0B,// Options5
			0x0E,// Group
				0x08,// ArrayReference
					0x28,// 0x28 = handlers_Grp_0FA6
			0x51,// Gv_Ev_3b
				0xAF, 0x0F,// Xbts_r16_rm16
			0x10,// Xbts
			0x2B,// Eb_Gb_1
				0xC5, 0x0F,// Cmpxchg486_rm8_r8
			0x20,// Cmpxchg486A
		0x0E,// Group
			0x08,// ArrayReference
				0x28,// 0x28 = handlers_Grp_0FA6

	// 167 = 0xA7
	0x00,// Bitness
		0x0B,// Options5
			0x0E,// Group
				0x08,// ArrayReference
					0x29,// 0x29 = handlers_Grp_0FA7
			0x38,// Ev_Gv_3b
				0xC3, 0x0F,// Ibts_rm16_r16
			0x10,// Xbts
			0x38,// Ev_Gv_3b
				0xC6, 0x0F,// Cmpxchg486_rm16_r16
			0x20,// Cmpxchg486A
		0x0E,// Group
			0x08,// ArrayReference
				0x29,// 0x29 = handlers_Grp_0FA7

	// 168 = 0xA8
	0x88,// PushOpSizeReg_4a
		0xC8, 0x0F,// Pushw_GS
		0x4C,// GS

	// 169 = 0xA9
	0x88,// PushOpSizeReg_4a
		0xCB, 0x0F,// Popw_GS
		0x4C,// GS

	// 170 = 0xAA
	0xA4,// Simple
		0xCE, 0x0F,// Rsm

	// 171 = 0xAB
	0x39,// Ev_Gv_4
		0xCF, 0x0F,// Bts_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 172 = 0xAC
	0x3B,// Ev_Gv_Ib
		0xD2, 0x0F,// Shrd_rm16_r16_imm8

	// 173 = 0xAD
	0x3A,// Ev_Gv_CL
		0xD5, 0x0F,// Shrd_rm16_r16_CL

	// 174 = 0xAE
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x33,// 0x33 = handlers_Grp_0FAE_lo
		0x08,// ArrayReference
			0x34,// 0x34 = handlers_Grp_0FAE_hi

	// 175 = 0xAF
	0x50,// Gv_Ev_3a
		0x96, 0x10,// Imul_r16_rm16

	// 176 = 0xB0
	0x2C,// Eb_Gb_2
		0x99, 0x10,// Cmpxchg_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 177 = 0xB1
	0x39,// Ev_Gv_4
		0x9A, 0x10,// Cmpxchg_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 178 = 0xB2
	0x5D,// Gv_Mp_3
		0x9D, 0x10,// Lss_r16_m1616

	// 179 = 0xB3
	0x39,// Ev_Gv_4
		0xA0, 0x10,// Btr_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 180 = 0xB4
	0x5D,// Gv_Mp_3
		0xA3, 0x10,// Lfs_r16_m1616

	// 181 = 0xB5
	0x5D,// Gv_Mp_3
		0xA6, 0x10,// Lgs_r16_m1616

	// 182 = 0xB6
	0x4D,// Gv_Eb
		0xA9, 0x10,// Movzx_r16_rm8

	// 183 = 0xB7
	0x58,// Gv_Ew
		0xAC, 0x10,// Movzx_r16_rm16

	// 184 = 0xB8
	0x0A,// Options3
		0x12,// MandatoryPrefix4
			0x02,// Invalid
			0x02,// Invalid
			0x50,// Gv_Ev_3a
				0xB1, 0x10,// Popcnt_r16_rm16
			0x02,// Invalid
			0x1C,// 0x1C
		0x00,// Bitness
			0x6B,// Jdisp
				0xAF, 0x10,// Jmpe_disp16
			0x12,// MandatoryPrefix4
				0x02,// Invalid
				0x02,// Invalid
				0x50,// Gv_Ev_3a
					0xB1, 0x10,// Popcnt_r16_rm16
				0x02,// Invalid
				0x1C,// 0x1C
		0x80, 0x20,// Jmpe

	// 185 = 0xB9
	0x50,// Gv_Ev_3a
		0xB4, 0x10,// Ud1_r16_rm16

	// 186 = 0xBA
	0x0E,// Group
		0x08,// ArrayReference
			0x2A,// 0x2A = handlers_Grp_0FBA

	// 187 = 0xBB
	0x39,// Ev_Gv_4
		0xC3, 0x10,// Btc_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 188 = 0xBC
	0x0A,// Options3
		0x12,// MandatoryPrefix4
			0x50,// Gv_Ev_3a
				0xC6, 0x10,// Bsf_r16_rm16
			0x50,// Gv_Ev_3a
				0xC6, 0x10,// Bsf_r16_rm16
			0x50,// Gv_Ev_3a
				0xC9, 0x10,// Tzcnt_r16_rm16
			0x50,// Gv_Ev_3a
				0xC6, 0x10,// Bsf_r16_rm16
			0x14,// 0x14
		0x50,// Gv_Ev_3a
			0xC6, 0x10,// Bsf_r16_rm16
		0x80, 0x80, 0x04,// NoMPFX_0FBC

	// 189 = 0xBD
	0x0A,// Options3
		0x12,// MandatoryPrefix4
			0x50,// Gv_Ev_3a
				0xCC, 0x10,// Bsr_r16_rm16
			0x50,// Gv_Ev_3a
				0xCC, 0x10,// Bsr_r16_rm16
			0x50,// Gv_Ev_3a
				0xCF, 0x10,// Lzcnt_r16_rm16
			0x50,// Gv_Ev_3a
				0xCC, 0x10,// Bsr_r16_rm16
			0x14,// 0x14
		0x50,// Gv_Ev_3a
			0xCC, 0x10,// Bsr_r16_rm16
		0x80, 0x80, 0x08,// NoMPFX_0FBD

	// 190 = 0xBE
	0x4D,// Gv_Eb
		0xD2, 0x10,// Movsx_r16_rm8

	// 191 = 0xBF
	0x58,// Gv_Ew
		0xD5, 0x10,// Movsx_r16_rm16

	// 192 = 0xC0
	0x2C,// Eb_Gb_2
		0xD8, 0x10,// Xadd_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 193 = 0xC1
	0x39,// Ev_Gv_4
		0xD9, 0x10,// Xadd_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 194 = 0xC2
	0x11,// MandatoryPrefix
		0xB9,// VWIb_2
			0xDC, 0x10,// Cmpps_xmm_xmmm128_imm8
		0xB9,// VWIb_2
			0xE2, 0x10,// Cmppd_xmm_xmmm128_imm8
		0xB9,// VWIb_2
			0xE8, 0x10,// Cmpss_xmm_xmmm32_imm8
		0xB9,// VWIb_2
			0xEB, 0x10,// Cmpsd_xmm_xmmm64_imm8

	// 195 = 0xC3
	0x11,// MandatoryPrefix
		0x7B,// Mv_Gv_REXW
			0xEE, 0x10,// Movnti_m32_r32
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 196 = 0xC4
	0x11,// MandatoryPrefix
		0x80,// P_Ev_Ib
			0xF0, 0x10,// Pinsrw_mm_r32m16_imm8
		0xBB,// VX_E_Ib
			0xF2, 0x10,// Pinsrw_xmm_r32m16_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 197 = 0xC5
	0x11,// MandatoryPrefix
		0x60,// Gv_N_Ib_REX
			0xF8, 0x10,// Pextrw_r32_mm_imm8
		0x09,// RM
			0x53,// Gv_Ev_Ib_REX
				0xFA, 0x10,// Pextrw_r32_xmm_imm8
			0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid

	// 198 = 0xC6
	0x11,// MandatoryPrefix
		0xB9,// VWIb_2
			0x80, 0x11,// Shufps_xmm_xmmm128_imm8
		0xB9,// VWIb_2
			0x86, 0x11,// Shufpd_xmm_xmmm128_imm8
		0x02,// Invalid
		0x02,// Invalid

	// 199 = 0xC7
	0x0E,// Group
		0x08,// ArrayReference
			0x2B,// 0x2B = handlers_Grp_0FC7

	// 200 = 0xC8
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x00,// 0x0

	// 201 = 0xC9
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x01,// 0x1

	// 202 = 0xCA
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x02,// 0x2

	// 203 = 0xCB
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x03,// 0x3

	// 204 = 0xCC
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x04,// 0x4

	// 205 = 0xCD
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x05,// 0x5

	// 206 = 0xCE
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x06,// 0x6

	// 207 = 0xCF
	0xAD,// SimpleReg
		0xA0, 0x11,// Bswap_r16
		0x07,// 0x7

	// 208 = 0xD0
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xA3, 0x11,// Addsubpd_xmm_xmmm128
		0x02,// Invalid
		0xB7,// VW_2
			0xA6, 0x11,// Addsubps_xmm_xmmm128

	// 209 = 0xD1
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xA9, 0x11,// Psrlw_mm_mmm64
		0xB7,// VW_2
			0xAA, 0x11,// Psrlw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 210 = 0xD2
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB0, 0x11,// Psrld_mm_mmm64
		0xB7,// VW_2
			0xB1, 0x11,// Psrld_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 211 = 0xD3
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB7, 0x11,// Psrlq_mm_mmm64
		0xB7,// VW_2
			0xB8, 0x11,// Psrlq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 212 = 0xD4
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xBE, 0x11,// Paddq_mm_mmm64
		0xB7,// VW_2
			0xBF, 0x11,// Paddq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 213 = 0xD5
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xC5, 0x11,// Pmullw_mm_mmm64
		0xB7,// VW_2
			0xC6, 0x11,// Pmullw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 214 = 0xD6
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xBE,// WV
			0xCC, 0x11,// Movq_xmmm64_xmm
		0xB4,// VN
			0xCF, 0x11,// Movq2dq_xmm_mm
		0x83,// P_R
			0xD0, 0x11,// Movdq2q_mm_xmm

	// 215 = 0xD7
	0x11,// MandatoryPrefix
		0x5F,// Gv_N
			0xD1, 0x11,// Pmovmskb_r32_mm
		0x61,// Gv_RX
			0xD3, 0x11,// Pmovmskb_r32_xmm
		0x02,// Invalid
		0x02,// Invalid

	// 216 = 0xD8
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xD9, 0x11,// Psubusb_mm_mmm64
		0xB7,// VW_2
			0xDA, 0x11,// Psubusb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 217 = 0xD9
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xE0, 0x11,// Psubusw_mm_mmm64
		0xB7,// VW_2
			0xE1, 0x11,// Psubusw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 218 = 0xDA
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xE7, 0x11,// Pminub_mm_mmm64
		0xB7,// VW_2
			0xE8, 0x11,// Pminub_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 219 = 0xDB
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xEE, 0x11,// Pand_mm_mmm64
		0xB7,// VW_2
			0xEF, 0x11,// Pand_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 220 = 0xDC
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xF8, 0x11,// Paddusb_mm_mmm64
		0xB7,// VW_2
			0xF9, 0x11,// Paddusb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 221 = 0xDD
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xFF, 0x11,// Paddusw_mm_mmm64
		0xB7,// VW_2
			0x80, 0x12,// Paddusw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 222 = 0xDE
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x86, 0x12,// Pmaxub_mm_mmm64
		0xB7,// VW_2
			0x87, 0x12,// Pmaxub_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 223 = 0xDF
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x8D, 0x12,// Pandn_mm_mmm64
		0xB7,// VW_2
			0x8E, 0x12,// Pandn_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 224 = 0xE0
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x97, 0x12,// Pavgb_mm_mmm64
		0xB7,// VW_2
			0x98, 0x12,// Pavgb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 225 = 0xE1
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x9E, 0x12,// Psraw_mm_mmm64
		0xB7,// VW_2
			0x9F, 0x12,// Psraw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 226 = 0xE2
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xA5, 0x12,// Psrad_mm_mmm64
		0xB7,// VW_2
			0xA6, 0x12,// Psrad_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 227 = 0xE3
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xAF, 0x12,// Pavgw_mm_mmm64
		0xB7,// VW_2
			0xB0, 0x12,// Pavgw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 228 = 0xE4
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB6, 0x12,// Pmulhuw_mm_mmm64
		0xB7,// VW_2
			0xB7, 0x12,// Pmulhuw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 229 = 0xE5
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xBD, 0x12,// Pmulhw_mm_mmm64
		0xB7,// VW_2
			0xBE, 0x12,// Pmulhw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 230 = 0xE6
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0xB7,// VW_2
			0xC4, 0x12,// Cvttpd2dq_xmm_xmmm128
		0xB7,// VW_2
			0xCA, 0x12,// Cvtdq2pd_xmm_xmmm64
		0xB7,// VW_2
			0xD3, 0x12,// Cvtpd2dq_xmm_xmmm128

	// 231 = 0xE7
	0x11,// MandatoryPrefix
		0x77,// MP
			0xD9, 0x12,// Movntq_m64_mm
		0x79,// MV
			0xDA, 0x12,// Movntdq_m128_xmm
		0x02,// Invalid
		0x02,// Invalid

	// 232 = 0xE8
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xE0, 0x12,// Psubsb_mm_mmm64
		0xB7,// VW_2
			0xE1, 0x12,// Psubsb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 233 = 0xE9
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xE7, 0x12,// Psubsw_mm_mmm64
		0xB7,// VW_2
			0xE8, 0x12,// Psubsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 234 = 0xEA
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xEE, 0x12,// Pminsw_mm_mmm64
		0xB7,// VW_2
			0xEF, 0x12,// Pminsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 235 = 0xEB
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xF5, 0x12,// Por_mm_mmm64
		0xB7,// VW_2
			0xF6, 0x12,// Por_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 236 = 0xEC
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xFF, 0x12,// Paddsb_mm_mmm64
		0xB7,// VW_2
			0x80, 0x13,// Paddsb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 237 = 0xED
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x86, 0x13,// Paddsw_mm_mmm64
		0xB7,// VW_2
			0x87, 0x13,// Paddsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 238 = 0xEE
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x8D, 0x13,// Pmaxsw_mm_mmm64
		0xB7,// VW_2
			0x8E, 0x13,// Pmaxsw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 239 = 0xEF
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0x94, 0x13,// Pxor_mm_mmm64
		0xB7,// VW_2
			0x95, 0x13,// Pxor_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 240 = 0xF0
	0x11,// MandatoryPrefix
		0x02,// Invalid
		0x02,// Invalid
		0x02,// Invalid
		0xB3,// VM
			0x9E, 0x13,// Lddqu_xmm_m128

	// 241 = 0xF1
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xA1, 0x13,// Psllw_mm_mmm64
		0xB7,// VW_2
			0xA2, 0x13,// Psllw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 242 = 0xF2
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xA8, 0x13,// Pslld_mm_mmm64
		0xB7,// VW_2
			0xA9, 0x13,// Pslld_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 243 = 0xF3
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xAF, 0x13,// Psllq_mm_mmm64
		0xB7,// VW_2
			0xB0, 0x13,// Psllq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 244 = 0xF4
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xB6, 0x13,// Pmuludq_mm_mmm64
		0xB7,// VW_2
			0xB7, 0x13,// Pmuludq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 245 = 0xF5
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xBD, 0x13,// Pmaddwd_mm_mmm64
		0xB7,// VW_2
			0xBE, 0x13,// Pmaddwd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 246 = 0xF6
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xC4, 0x13,// Psadbw_mm_mmm64
		0xB7,// VW_2
			0xC5, 0x13,// Psadbw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 247 = 0xF7
	0x11,// MandatoryPrefix
		0x8F,// rDI_P_N
			0xCB, 0x13,// Maskmovq_rDI_mm_mm
		0x90,// rDI_VX_RX
			0xCC, 0x13,// Maskmovdqu_rDI_xmm_xmm
		0x02,// Invalid
		0x02,// Invalid

	// 248 = 0xF8
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xCE, 0x13,// Psubb_mm_mmm64
		0xB7,// VW_2
			0xCF, 0x13,// Psubb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 249 = 0xF9
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xD5, 0x13,// Psubw_mm_mmm64
		0xB7,// VW_2
			0xD6, 0x13,// Psubw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 250 = 0xFA
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xDC, 0x13,// Psubd_mm_mmm64
		0xB7,// VW_2
			0xDD, 0x13,// Psubd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 251 = 0xFB
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xE3, 0x13,// Psubq_mm_mmm64
		0xB7,// VW_2
			0xE4, 0x13,// Psubq_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 252 = 0xFC
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xEA, 0x13,// Paddb_mm_mmm64
		0xB7,// VW_2
			0xEB, 0x13,// Paddb_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 253 = 0xFD
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xF1, 0x13,// Paddw_mm_mmm64
		0xB7,// VW_2
			0xF2, 0x13,// Paddw_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 254 = 0xFE
	0x11,// MandatoryPrefix
		0x81,// P_Q
			0xF8, 0x13,// Paddd_mm_mmm64
		0xB7,// VW_2
			0xF9, 0x13,// Paddd_xmm_xmmm128
		0x02,// Invalid
		0x02,// Invalid

	// 255 = 0xFF
	0x0A,// Options3
		0x50,// Gv_Ev_3a
			0xFF, 0x13,// Ud0_r16_rm16
		0xA4,// Simple
			0xFD, 0x20,// Ud0
		0x02,// AMD

	// Handlers_MAP0
	0x01,// ArrayReference
	0x80, 0x02,// 0x100
	// 0 = 0x00
	0x2C,// Eb_Gb_2
		0x05,// Add_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 1 = 0x01
	0x39,// Ev_Gv_4
		0x06,// Add_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 2 = 0x02
	0x4B,// Gb_Eb
		0x09,// Add_r8_rm8

	// 3 = 0x03
	0x50,// Gv_Ev_3a
		0x0A,// Add_r16_rm16

	// 4 = 0x04
	0x9B,// RegIb
		0x0D,// Add_AL_imm8
		0x01,// AL

	// 5 = 0x05
	0x93,// Reg_Iz
		0x0E,// Add_AX_imm16

	// 6 = 0x06
	0x00,// Bitness
		0x89,// PushOpSizeReg_4b
			0x11,// Pushw_ES
			0x47,// ES
		0x02,// Invalid

	// 7 = 0x07
	0x00,// Bitness
		0x89,// PushOpSizeReg_4b
			0x13,// Popw_ES
			0x47,// ES
		0x02,// Invalid

	// 8 = 0x08
	0x2C,// Eb_Gb_2
		0x15,// Or_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 9 = 0x09
	0x39,// Ev_Gv_4
		0x16,// Or_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 10 = 0x0A
	0x4B,// Gb_Eb
		0x19,// Or_r8_rm8

	// 11 = 0x0B
	0x50,// Gv_Ev_3a
		0x1A,// Or_r16_rm16

	// 12 = 0x0C
	0x9B,// RegIb
		0x1D,// Or_AL_imm8
		0x01,// AL

	// 13 = 0x0D
	0x93,// Reg_Iz
		0x1E,// Or_AX_imm16

	// 14 = 0x0E
	0x00,// Bitness
		0x89,// PushOpSizeReg_4b
			0x21,// Pushw_CS
			0x48,// CS
		0x02,// Invalid

	// 15 = 0x0F
	0x0D,// AnotherTable
		0x08,// ArrayReference
			0x50,// 0x50 = Handlers_0F

	// 16 = 0x10
	0x2C,// Eb_Gb_2
		0x24,// Adc_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 17 = 0x11
	0x39,// Ev_Gv_4
		0x25,// Adc_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 18 = 0x12
	0x4B,// Gb_Eb
		0x28,// Adc_r8_rm8

	// 19 = 0x13
	0x50,// Gv_Ev_3a
		0x29,// Adc_r16_rm16

	// 20 = 0x14
	0x9B,// RegIb
		0x2C,// Adc_AL_imm8
		0x01,// AL

	// 21 = 0x15
	0x93,// Reg_Iz
		0x2D,// Adc_AX_imm16

	// 22 = 0x16
	0x00,// Bitness
		0x89,// PushOpSizeReg_4b
			0x30,// Pushw_SS
			0x49,// SS
		0x02,// Invalid

	// 23 = 0x17
	0x00,// Bitness
		0x89,// PushOpSizeReg_4b
			0x32,// Popw_SS
			0x49,// SS
		0x02,// Invalid

	// 24 = 0x18
	0x2C,// Eb_Gb_2
		0x34,// Sbb_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 25 = 0x19
	0x39,// Ev_Gv_4
		0x35,// Sbb_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 26 = 0x1A
	0x4B,// Gb_Eb
		0x38,// Sbb_r8_rm8

	// 27 = 0x1B
	0x50,// Gv_Ev_3a
		0x39,// Sbb_r16_rm16

	// 28 = 0x1C
	0x9B,// RegIb
		0x3C,// Sbb_AL_imm8
		0x01,// AL

	// 29 = 0x1D
	0x93,// Reg_Iz
		0x3D,// Sbb_AX_imm16

	// 30 = 0x1E
	0x00,// Bitness
		0x89,// PushOpSizeReg_4b
			0x40,// Pushw_DS
			0x4A,// DS
		0x02,// Invalid

	// 31 = 0x1F
	0x00,// Bitness
		0x89,// PushOpSizeReg_4b
			0x42,// Popw_DS
			0x4A,// DS
		0x02,// Invalid

	// 32 = 0x20
	0x2C,// Eb_Gb_2
		0x44,// And_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 33 = 0x21
	0x39,// Ev_Gv_4
		0x45,// And_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 34 = 0x22
	0x4B,// Gb_Eb
		0x48,// And_r8_rm8

	// 35 = 0x23
	0x50,// Gv_Ev_3a
		0x49,// And_r16_rm16

	// 36 = 0x24
	0x9B,// RegIb
		0x4C,// And_AL_imm8
		0x01,// AL

	// 37 = 0x25
	0x93,// Reg_Iz
		0x4D,// And_AX_imm16

	// 38 = 0x26
	0xCE,// PrefixEsCsSsDs
		0x47,// ES

	// 39 = 0x27
	0x00,// Bitness
		0xA4,// Simple
			0x50,// Daa
		0x02,// Invalid

	// 40 = 0x28
	0x2C,// Eb_Gb_2
		0x51,// Sub_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 41 = 0x29
	0x39,// Ev_Gv_4
		0x52,// Sub_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 42 = 0x2A
	0x4B,// Gb_Eb
		0x55,// Sub_r8_rm8

	// 43 = 0x2B
	0x50,// Gv_Ev_3a
		0x56,// Sub_r16_rm16

	// 44 = 0x2C
	0x9B,// RegIb
		0x59,// Sub_AL_imm8
		0x01,// AL

	// 45 = 0x2D
	0x93,// Reg_Iz
		0x5A,// Sub_AX_imm16

	// 46 = 0x2E
	0xCE,// PrefixEsCsSsDs
		0x48,// CS

	// 47 = 0x2F
	0x00,// Bitness
		0xA4,// Simple
			0x5D,// Das
		0x02,// Invalid

	// 48 = 0x30
	0x2C,// Eb_Gb_2
		0x5E,// Xor_rm8_r8
		0x0B,// Xacquire, Xrelease, Lock

	// 49 = 0x31
	0x39,// Ev_Gv_4
		0x5F,// Xor_rm16_r16
		0x0B,// Xacquire, Xrelease, Lock

	// 50 = 0x32
	0x4B,// Gb_Eb
		0x62,// Xor_r8_rm8

	// 51 = 0x33
	0x50,// Gv_Ev_3a
		0x63,// Xor_r16_rm16

	// 52 = 0x34
	0x9B,// RegIb
		0x66,// Xor_AL_imm8
		0x01,// AL

	// 53 = 0x35
	0x93,// Reg_Iz
		0x67,// Xor_AX_imm16

	// 54 = 0x36
	0xCE,// PrefixEsCsSsDs
		0x49,// SS

	// 55 = 0x37
	0x00,// Bitness
		0xA4,// Simple
			0x6A,// Aaa
		0x02,// Invalid

	// 56 = 0x38
	0x2B,// Eb_Gb_1
		0x6B,// Cmp_rm8_r8

	// 57 = 0x39
	0x37,// Ev_Gv_3a
		0x6C,// Cmp_rm16_r16

	// 58 = 0x3A
	0x4B,// Gb_Eb
		0x6F,// Cmp_r8_rm8

	// 59 = 0x3B
	0x50,// Gv_Ev_3a
		0x70,// Cmp_r16_rm16

	// 60 = 0x3C
	0x9B,// RegIb
		0x73,// Cmp_AL_imm8
		0x01,// AL

	// 61 = 0x3D
	0x93,// Reg_Iz
		0x74,// Cmp_AX_imm16

	// 62 = 0x3E
	0xCE,// PrefixEsCsSsDs
		0x4A,// DS

	// 63 = 0x3F
	0x00,// Bitness
		0xA4,// Simple
			0x77,// Aas
		0x02,// Invalid

	// 64 = 0x40
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x00,// 0x0
		0x00,// 0x0

	// 65 = 0x41
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x01,// 0x1
		0x01,// 0x1

	// 66 = 0x42
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x02,// 0x2
		0x02,// 0x2

	// 67 = 0x43
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x03,// 0x3
		0x03,// 0x3

	// 68 = 0x44
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x04,// 0x4
		0x04,// 0x4

	// 69 = 0x45
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x05,// 0x5
		0x05,// 0x5

	// 70 = 0x46
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x06,// 0x6
		0x06,// 0x6

	// 71 = 0x47
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x78,// Inc_r16
			0x07,// 0x7
		0x07,// 0x7

	// 72 = 0x48
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x00,// 0x0
		0x08,// 0x8

	// 73 = 0x49
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x01,// 0x1
		0x09,// 0x9

	// 74 = 0x4A
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x02,// 0x2
		0x0A,// 0xA

	// 75 = 0x4B
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x03,// 0x3
		0x0B,// 0xB

	// 76 = 0x4C
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x04,// 0x4
		0x0C,// 0xC

	// 77 = 0x4D
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x05,// 0x5
		0x0D,// 0xD

	// 78 = 0x4E
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x06,// 0x6
		0x0E,// 0xE

	// 79 = 0x4F
	0xD5,// PrefixREX
		0xAD,// SimpleReg
			0x7A,// Dec_r16
			0x07,// 0x7
		0x0F,// 0xF

	// 80 = 0x50
	0x8B,// PushSimpleReg
		0x00,// 0x0
		0x7C,// Push_r16

	// 81 = 0x51
	0x8B,// PushSimpleReg
		0x01,// 0x1
		0x7C,// Push_r16

	// 82 = 0x52
	0x8B,// PushSimpleReg
		0x02,// 0x2
		0x7C,// Push_r16

	// 83 = 0x53
	0x8B,// PushSimpleReg
		0x03,// 0x3
		0x7C,// Push_r16

	// 84 = 0x54
	0x8B,// PushSimpleReg
		0x04,// 0x4
		0x7C,// Push_r16

	// 85 = 0x55
	0x8B,// PushSimpleReg
		0x05,// 0x5
		0x7C,// Push_r16

	// 86 = 0x56
	0x8B,// PushSimpleReg
		0x06,// 0x6
		0x7C,// Push_r16

	// 87 = 0x57
	0x8B,// PushSimpleReg
		0x07,// 0x7
		0x7C,// Push_r16

	// 88 = 0x58
	0x8B,// PushSimpleReg
		0x00,// 0x0
		0x7F,// Pop_r16

	// 89 = 0x59
	0x8B,// PushSimpleReg
		0x01,// 0x1
		0x7F,// Pop_r16

	// 90 = 0x5A
	0x8B,// PushSimpleReg
		0x02,// 0x2
		0x7F,// Pop_r16

	// 91 = 0x5B
	0x8B,// PushSimpleReg
		0x03,// 0x3
		0x7F,// Pop_r16

	// 92 = 0x5C
	0x8B,// PushSimpleReg
		0x04,// 0x4
		0x7F,// Pop_r16

	// 93 = 0x5D
	0x8B,// PushSimpleReg
		0x05,// 0x5
		0x7F,// Pop_r16

	// 94 = 0x5E
	0x8B,// PushSimpleReg
		0x06,// 0x6
		0x7F,// Pop_r16

	// 95 = 0x5F
	0x8B,// PushSimpleReg
		0x07,// 0x7
		0x7F,// Pop_r16

	// 96 = 0x60
	0x00,// Bitness
		0xA7,// Simple2_3b
			0x82, 0x01,// Pushaw
			0x83, 0x01,// Pushad
			0x83, 0x01,// Pushad
		0x02,// Invalid

	// 97 = 0x61
	0x00,// Bitness
		0xA7,// Simple2_3b
			0x84, 0x01,// Popaw
			0x85, 0x01,// Popad
			0x85, 0x01,// Popad
		0x02,// Invalid

	// 98 = 0x62
	0x17,// EVEX
		0x5B,// Gv_Ma
			0x86, 0x01,// Bound_r16_m1616

	// 99 = 0x63
	0x00,// Bitness
		0xA3,// RvMw_Gw
			0x88, 0x01,// Arpl_rm16_r16
		0x56,// Gv_Ev2
			0x8A, 0x01,// Movsxd_r16_rm16

	// 100 = 0x64
	0xCF,// PrefixFsGs
		0x4B,// FS

	// 101 = 0x65
	0xCF,// PrefixFsGs
		0x4C,// GS

	// 102 = 0x66
	0xD0,// Prefix66

	// 103 = 0x67
	0xD1,// Prefix67

	// 104 = 0x68
	0x87,// PushIz
		0x8D, 0x01,// Push_imm16

	// 105 = 0x69
	0x54,// Gv_Ev_Iz
		0x90, 0x01,// Imul_r16_rm16_imm16

	// 106 = 0x6A
	0x86,// PushIb2
		0x93, 0x01,// Pushw_imm8

	// 107 = 0x6B
	0x52,// Gv_Ev_Ib
		0x96, 0x01,// Imul_r16_rm16_imm8

	// 108 = 0x6C
	0xC2,// Yb_Reg
		0x99, 0x01,// Insb_m8_DX
		0x17,// DX

	// 109 = 0x6D
	0xC5,// Yv_Reg2
		0x9A, 0x01,// Insw_m16_DX

	// 110 = 0x6E
	0x96,// Reg_Xb
		0x9C, 0x01,// Outsb_DX_m8
		0x17,// DX

	// 111 = 0x6F
	0x98,// Reg_Xv2
		0x9D, 0x01,// Outsw_DX_m16

	// 112 = 0x70
	0x69,// Jb
		0x9F, 0x01,// Jo_rel8_16

	// 113 = 0x71
	0x69,// Jb
		0xA2, 0x01,// Jno_rel8_16

	// 114 = 0x72
	0x69,// Jb
		0xA5, 0x01,// Jb_rel8_16

	// 115 = 0x73
	0x69,// Jb
		0xA8, 0x01,// Jae_rel8_16

	// 116 = 0x74
	0x69,// Jb
		0xAB, 0x01,// Je_rel8_16

	// 117 = 0x75
	0x69,// Jb
		0xAE, 0x01,// Jne_rel8_16

	// 118 = 0x76
	0x69,// Jb
		0xB1, 0x01,// Jbe_rel8_16

	// 119 = 0x77
	0x69,// Jb
		0xB4, 0x01,// Ja_rel8_16

	// 120 = 0x78
	0x69,// Jb
		0xB7, 0x01,// Js_rel8_16

	// 121 = 0x79
	0x69,// Jb
		0xBA, 0x01,// Jns_rel8_16

	// 122 = 0x7A
	0x69,// Jb
		0xBD, 0x01,// Jp_rel8_16

	// 123 = 0x7B
	0x69,// Jb
		0xC0, 0x01,// Jnp_rel8_16

	// 124 = 0x7C
	0x69,// Jb
		0xC3, 0x01,// Jl_rel8_16

	// 125 = 0x7D
	0x69,// Jb
		0xC6, 0x01,// Jge_rel8_16

	// 126 = 0x7E
	0x69,// Jb
		0xC9, 0x01,// Jle_rel8_16

	// 127 = 0x7F
	0x69,// Jb
		0xCC, 0x01,// Jg_rel8_16

	// 128 = 0x80
	0x0E,// Group
		0x08,// ArrayReference
			0x10,// 0x10 = handlers_Grp_80

	// 129 = 0x81
	0x0E,// Group
		0x08,// ArrayReference
			0x11,// 0x11 = handlers_Grp_81

	// 130 = 0x82
	0x00,// Bitness
		0x0E,// Group
			0x08,// ArrayReference
				0x12,// 0x12 = handlers_Grp_82
		0x02,// Invalid

	// 131 = 0x83
	0x0E,// Group
		0x08,// ArrayReference
			0x13,// 0x13 = handlers_Grp_83

	// 132 = 0x84
	0x2B,// Eb_Gb_1
		0x8F, 0x02,// Test_rm8_r8

	// 133 = 0x85
	0x37,// Ev_Gv_3a
		0x90, 0x02,// Test_rm16_r16

	// 134 = 0x86
	0x2C,// Eb_Gb_2
		0x93, 0x02,// Xchg_rm8_r8
		0x0F,// Xacquire, Xrelease, XacquireXreleaseNoLock, Lock

	// 135 = 0x87
	0x39,// Ev_Gv_4
		0x94, 0x02,// Xchg_rm16_r16
		0x0F,// Xacquire, Xrelease, XacquireXreleaseNoLock, Lock

	// 136 = 0x88
	0x2C,// Eb_Gb_2
		0x97, 0x02,// Mov_rm8_r8
		0x06,// Xrelease, XacquireXreleaseNoLock

	// 137 = 0x89
	0x39,// Ev_Gv_4
		0x98, 0x02,// Mov_rm16_r16
		0x06,// Xrelease, XacquireXreleaseNoLock

	// 138 = 0x8A
	0x4B,// Gb_Eb
		0x9B, 0x02,// Mov_r8_rm8

	// 139 = 0x8B
	0x50,// Gv_Ev_3a
		0x9C, 0x02,// Mov_r16_rm16

	// 140 = 0x8C
	0x45,// Ev_Sw
		0x9F, 0x02,// Mov_rm16_Sreg

	// 141 = 0x8D
	0x59,// Gv_M
		0xA2, 0x02,// Lea_r16_m

	// 142 = 0x8E
	0xB1,// Sw_Ev
		0xA5, 0x02,// Mov_Sreg_rm16

	// 143 = 0x8F
	0x1A,// XOP
		0x0E,// Group
			0x08,// ArrayReference
				0x14,// 0x14 = handlers_Grp_8F

	// 144 = 0x90
	0xC0,// Xchg_Reg_rAX
		0x00,// 0x0

	// 145 = 0x91
	0xC0,// Xchg_Reg_rAX
		0x01,// 0x1

	// 146 = 0x92
	0xC0,// Xchg_Reg_rAX
		0x02,// 0x2

	// 147 = 0x93
	0xC0,// Xchg_Reg_rAX
		0x03,// 0x3

	// 148 = 0x94
	0xC0,// Xchg_Reg_rAX
		0x04,// 0x4

	// 149 = 0x95
	0xC0,// Xchg_Reg_rAX
		0x05,// 0x5

	// 150 = 0x96
	0xC0,// Xchg_Reg_rAX
		0x06,// 0x6

	// 151 = 0x97
	0xC0,// Xchg_Reg_rAX
		0x07,// 0x7

	// 152 = 0x98
	0xA6,// Simple2_3a
		0xB2, 0x02,// Cbw

	// 153 = 0x99
	0xA6,// Simple2_3a
		0xB5, 0x02,// Cwd

	// 154 = 0x9A
	0x00,// Bitness
		0x1C,// Ap
			0xB8, 0x02,// Call_ptr1616
		0x02,// Invalid

	// 155 = 0x9B
	0xA4,// Simple
		0xBA, 0x02,// Wait

	// 156 = 0x9C
	0x8A,// PushSimple2
		0xBB, 0x02,// Pushfw

	// 157 = 0x9D
	0x8A,// PushSimple2
		0xBE, 0x02,// Popfw

	// 158 = 0x9E
	0x00,// Bitness
		0xA4,// Simple
			0xC1, 0x02,// Sahf
		0x0A,// Options3
			0xA4,// Simple
				0xC1, 0x02,// Sahf
			0x02,// Invalid
			0x80, 0x80, 0x10,// NoLahfSahf64

	// 159 = 0x9F
	0x00,// Bitness
		0xA4,// Simple
			0xC2, 0x02,// Lahf
		0x0A,// Options3
			0xA4,// Simple
				0xC2, 0x02,// Lahf
			0x02,// Invalid
			0x80, 0x80, 0x10,// NoLahfSahf64

	// 160 = 0xA0
	0x94,// Reg_Ob
		0xC3, 0x02,// Mov_AL_moffs8
		0x01,// AL

	// 161 = 0xA1
	0x95,// Reg_Ov
		0xC4, 0x02,// Mov_AX_moffs16

	// 162 = 0xA2
	0x7D,// Ob_Reg
		0xC7, 0x02,// Mov_moffs8_AL
		0x01,// AL

	// 163 = 0xA3
	0x7E,// Ov_Reg
		0xC8, 0x02,// Mov_moffs16_AX

	// 164 = 0xA4
	0xC3,// Yb_Xb
		0xCB, 0x02,// Movsb_m8_m8

	// 165 = 0xA5
	0xC6,// Yv_Xv
		0xCC, 0x02,// Movsw_m16_m16

	// 166 = 0xA6
	0xBF,// Xb_Yb
		0xCF, 0x02,// Cmpsb_m8_m8

	// 167 = 0xA7
	0xC1,// Xv_Yv
		0xD0, 0x02,// Cmpsw_m16_m16

	// 168 = 0xA8
	0x9B,// RegIb
		0xD3, 0x02,// Test_AL_imm8
		0x01,// AL

	// 169 = 0xA9
	0x93,// Reg_Iz
		0xD4, 0x02,// Test_AX_imm16

	// 170 = 0xAA
	0xC2,// Yb_Reg
		0xD7, 0x02,// Stosb_m8_AL
		0x01,// AL

	// 171 = 0xAB
	0xC4,// Yv_Reg
		0xD8, 0x02,// Stosw_m16_AX

	// 172 = 0xAC
	0x96,// Reg_Xb
		0xDB, 0x02,// Lodsb_AL_m8
		0x01,// AL

	// 173 = 0xAD
	0x97,// Reg_Xv
		0xDC, 0x02,// Lodsw_AX_m16

	// 174 = 0xAE
	0x99,// Reg_Yb
		0xDF, 0x02,// Scasb_AL_m8
		0x01,// AL

	// 175 = 0xAF
	0x9A,// Reg_Yv
		0xE0, 0x02,// Scasw_AX_m16

	// 176 = 0xB0
	0x9C,// RegIb3
		0x00,// 0x0

	// 177 = 0xB1
	0x9C,// RegIb3
		0x01,// 0x1

	// 178 = 0xB2
	0x9C,// RegIb3
		0x02,// 0x2

	// 179 = 0xB3
	0x9C,// RegIb3
		0x03,// 0x3

	// 180 = 0xB4
	0x9C,// RegIb3
		0x04,// 0x4

	// 181 = 0xB5
	0x9C,// RegIb3
		0x05,// 0x5

	// 182 = 0xB6
	0x9C,// RegIb3
		0x06,// 0x6

	// 183 = 0xB7
	0x9C,// RegIb3
		0x07,// 0x7

	// 184 = 0xB8
	0x9D,// RegIz2
		0x00,// 0x0

	// 185 = 0xB9
	0x9D,// RegIz2
		0x01,// 0x1

	// 186 = 0xBA
	0x9D,// RegIz2
		0x02,// 0x2

	// 187 = 0xBB
	0x9D,// RegIz2
		0x03,// 0x3

	// 188 = 0xBC
	0x9D,// RegIz2
		0x04,// 0x4

	// 189 = 0xBD
	0x9D,// RegIz2
		0x05,// 0x5

	// 190 = 0xBE
	0x9D,// RegIz2
		0x06,// 0x6

	// 191 = 0xBF
	0x9D,// RegIz2
		0x07,// 0x7

	// 192 = 0xC0
	0x0E,// Group
		0x08,// ArrayReference
			0x15,// 0x15 = handlers_Grp_C0

	// 193 = 0xC1
	0x0E,// Group
		0x08,// ArrayReference
			0x16,// 0x16 = handlers_Grp_C1

	// 194 = 0xC2
	0x21,// BranchIw
		0x87, 0x03,// Retnw_imm16

	// 195 = 0xC3
	0x22,// BranchSimple
		0x8A, 0x03,// Retnw

	// 196 = 0xC4
	0x19,// VEX3
		0x5C,// Gv_Mp_2
			0x8D, 0x03,// Les_r16_m1616

	// 197 = 0xC5
	0x18,// VEX2
		0x5C,// Gv_Mp_2
			0x8F, 0x03,// Lds_r16_m1616

	// 198 = 0xC6
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x2C,// 0x2C = handlers_Grp_C6_lo
		0x08,// ArrayReference
			0x2D,// 0x2D = handlers_Grp_C6_hi

	// 199 = 0xC7
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x2E,// 0x2E = handlers_Grp_C7_lo
		0x08,// ArrayReference
			0x2F,// 0x2F = handlers_Grp_C7_hi

	// 200 = 0xC8
	0x68,// Iw_Ib
		0x98, 0x03,// Enterw_imm16_imm8

	// 201 = 0xC9
	0xA9,// Simple3
		0x9B, 0x03,// Leavew

	// 202 = 0xCA
	0xA8,// Simple2Iw
		0x9E, 0x03,// Retfw_imm16

	// 203 = 0xCB
	0xA6,// Simple2_3a
		0xA1, 0x03,// Retfw

	// 204 = 0xCC
	0xA4,// Simple
		0xA4, 0x03,// Int3

	// 205 = 0xCD
	0x64,// Ib
		0xA5, 0x03,// Int_imm8

	// 206 = 0xCE
	0x00,// Bitness
		0xA4,// Simple
			0xA6, 0x03,// Into
		0x02,// Invalid

	// 207 = 0xCF
	0xA6,// Simple2_3a
		0xA7, 0x03,// Iretw

	// 208 = 0xD0
	0x0E,// Group
		0x08,// ArrayReference
			0x17,// 0x17 = handlers_Grp_D0

	// 209 = 0xD1
	0x0E,// Group
		0x08,// ArrayReference
			0x18,// 0x18 = handlers_Grp_D1

	// 210 = 0xD2
	0x0E,// Group
		0x08,// ArrayReference
			0x19,// 0x19 = handlers_Grp_D2

	// 211 = 0xD3
	0x0E,// Group
		0x08,// ArrayReference
			0x1A,// 0x1A = handlers_Grp_D3

	// 212 = 0xD4
	0x00,// Bitness
		0x64,// Ib
			0xEA, 0x03,// Aam_imm8
		0x02,// Invalid

	// 213 = 0xD5
	0x00,// Bitness
		0x64,// Ib
			0xEB, 0x03,// Aad_imm8
		0x02,// Invalid

	// 214 = 0xD6
	0x00,// Bitness
		0xA4,// Simple
			0xEC, 0x03,// Salc
		0x02,// Invalid

	// 215 = 0xD7
	0x72,// MemBx
		0xED, 0x03,// Xlat_m8

	// 216 = 0xD8
	0x10,// Group8x8
		0x08,// ArrayReference
			0x00,// 0x0 = handlers_FPU_D8_low
		0x08,// ArrayReference
			0x01,// 0x1 = handlers_FPU_D8_high

	// 217 = 0xD9
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x02,// 0x2 = handlers_FPU_D9_low
		0x08,// ArrayReference
			0x03,// 0x3 = handlers_FPU_D9_high

	// 218 = 0xDA
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x04,// 0x4 = handlers_FPU_DA_low
		0x08,// ArrayReference
			0x05,// 0x5 = handlers_FPU_DA_high

	// 219 = 0xDB
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x06,// 0x6 = handlers_FPU_DB_low
		0x08,// ArrayReference
			0x07,// 0x7 = handlers_FPU_DB_high

	// 220 = 0xDC
	0x10,// Group8x8
		0x08,// ArrayReference
			0x08,// 0x8 = handlers_FPU_DC_low
		0x08,// ArrayReference
			0x09,// 0x9 = handlers_FPU_DC_high

	// 221 = 0xDD
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x0A,// 0xA = handlers_FPU_DD_low
		0x08,// ArrayReference
			0x0B,// 0xB = handlers_FPU_DD_high

	// 222 = 0xDE
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x0C,// 0xC = handlers_FPU_DE_low
		0x08,// ArrayReference
			0x0D,// 0xD = handlers_FPU_DE_high

	// 223 = 0xDF
	0x0F,// Group8x64
		0x08,// ArrayReference
			0x0E,// 0xE = handlers_FPU_DF_low
		0x08,// ArrayReference
			0x0F,// 0xF = handlers_FPU_DF_high

	// 224 = 0xE0
	0x6A,// Jb2
		0x91, 0x05,// Loopne_rel8_16_CX
		0x93, 0x05,// Loopne_rel8_16_ECX
		0x96, 0x05,// Loopne_rel8_16_RCX
		0x92, 0x05,// Loopne_rel8_32_CX
		0x94, 0x05,// Loopne_rel8_32_ECX
		0x95, 0x05,// Loopne_rel8_64_ECX
		0x97, 0x05,// Loopne_rel8_64_RCX

	// 225 = 0xE1
	0x6A,// Jb2
		0x98, 0x05,// Loope_rel8_16_CX
		0x9A, 0x05,// Loope_rel8_16_ECX
		0x9D, 0x05,// Loope_rel8_16_RCX
		0x99, 0x05,// Loope_rel8_32_CX
		0x9B, 0x05,// Loope_rel8_32_ECX
		0x9C, 0x05,// Loope_rel8_64_ECX
		0x9E, 0x05,// Loope_rel8_64_RCX

	// 226 = 0xE2
	0x6A,// Jb2
		0x9F, 0x05,// Loop_rel8_16_CX
		0xA1, 0x05,// Loop_rel8_16_ECX
		0xA4, 0x05,// Loop_rel8_16_RCX
		0xA0, 0x05,// Loop_rel8_32_CX
		0xA2, 0x05,// Loop_rel8_32_ECX
		0xA3, 0x05,// Loop_rel8_64_ECX
		0xA5, 0x05,// Loop_rel8_64_RCX

	// 227 = 0xE3
	0x6A,// Jb2
		0xA6, 0x05,// Jcxz_rel8_16
		0xA8, 0x05,// Jecxz_rel8_16
		0xAB, 0x05,// Jrcxz_rel8_16
		0xA7, 0x05,// Jcxz_rel8_32
		0xA9, 0x05,// Jecxz_rel8_32
		0xAA, 0x05,// Jecxz_rel8_64
		0xAC, 0x05,// Jrcxz_rel8_64

	// 228 = 0xE4
	0x9B,// RegIb
		0xAD, 0x05,// In_AL_imm8
		0x01,// AL

	// 229 = 0xE5
	0x92,// Reg_Ib2
		0xAE, 0x05,// In_AX_imm8

	// 230 = 0xE6
	0x66,// IbReg
		0xB0, 0x05,// Out_imm8_AL
		0x01,// AL

	// 231 = 0xE7
	0x67,// IbReg2
		0xB1, 0x05,// Out_imm8_AX

	// 232 = 0xE8
	0x6D,// Jz
		0xB3, 0x05,// Call_rel16

	// 233 = 0xE9
	0x6D,// Jz
		0xB6, 0x05,// Jmp_rel16

	// 234 = 0xEA
	0x00,// Bitness
		0x1C,// Ap
			0xB9, 0x05,// Jmp_ptr1616
		0x02,// Invalid

	// 235 = 0xEB
	0x69,// Jb
		0xBB, 0x05,// Jmp_rel8_16

	// 236 = 0xEC
	0x1B,// AL_DX
		0xBE, 0x05,// In_AL_DX

	// 237 = 0xED
	0x27,// eAX_DX
		0xBF, 0x05,// In_AX_DX

	// 238 = 0xEE
	0x25,// DX_AL
		0xC1, 0x05,// Out_DX_AL

	// 239 = 0xEF
	0x26,// DX_eAX
		0xC2, 0x05,// Out_DX_AX

	// 240 = 0xF0
	0xD2,// PrefixF0

	// 241 = 0xF1
	0xA4,// Simple
		0xC4, 0x05,// Int1

	// 242 = 0xF2
	0xD3,// PrefixF2

	// 243 = 0xF3
	0xD4,// PrefixF3

	// 244 = 0xF4
	0xA4,// Simple
		0xC5, 0x05,// Hlt

	// 245 = 0xF5
	0xA4,// Simple
		0xC6, 0x05,// Cmc

	// 246 = 0xF6
	0x0E,// Group
		0x08,// ArrayReference
			0x1B,// 0x1B = handlers_Grp_F6

	// 247 = 0xF7
	0x0E,// Group
		0x08,// ArrayReference
			0x1C,// 0x1C = handlers_Grp_F7

	// 248 = 0xF8
	0xA4,// Simple
		0xE7, 0x05,// Clc

	// 249 = 0xF9
	0xA4,// Simple
		0xE8, 0x05,// Stc

	// 250 = 0xFA
	0xA4,// Simple
		0xE9, 0x05,// Cli

	// 251 = 0xFB
	0xA4,// Simple
		0xEA, 0x05,// Sti

	// 252 = 0xFC
	0xA4,// Simple
		0xEB, 0x05,// Cld

	// 253 = 0xFD
	0xA4,// Simple
		0xEC, 0x05,// Std

	// 254 = 0xFE
	0x0E,// Group
		0x08,// ArrayReference
			0x1D,// 0x1D = handlers_Grp_FE

	// 255 = 0xFF
	0x0E,// Group
		0x08,// ArrayReference
			0x1E,// 0x1E = handlers_Grp_FF
];
pub(super) const MAX_ID_NAMES: usize = 82;
#[allow(dead_code)]
pub(super) const HANDLERS_MAP0_INDEX: usize = 81;
